@@ -1,21 +1,23 @@
+import semantic_version
+
 from gdsfactory.component import Component
 from gdsfactory.config import __version__
 
 
 def grating_coupler(gc: Component) -> None:
     assert hasattr(
-        gc, "polarization"
+        gc.info, "polarization"
     ), f"{gc.name} does not have polarization attribute"
-    assert gc.polarization in [
+    assert gc.info.polarization in [
         "te",
         "tm",
     ], f"{gc.name} polarization  should be 'te' or 'tm'"
     assert hasattr(
-        gc, "wavelength"
+        gc.info, "wavelength"
     ), f"{gc.name} wavelength does not have wavelength attribute"
     assert (
-        500 < gc.wavelength < 2000
-    ), f"{gc.name} wavelength {gc.wavelength} should be in nm"
+        0.5 < gc.info.wavelength < 5.0
+    ), f"{gc.name} wavelength {gc.wavelength} should be in um"
     if "o1" not in gc.ports:
         print(f"grating_coupler {gc.name} should have a o1 port. It has {gc.ports}")
     if "o1" in gc.ports and gc.ports["o1"].orientation != 180:
@@ -25,21 +27,21 @@ def grating_coupler(gc: Component) -> None:
         )
 
 
-def version_equal_or_greater_than(version: str):
-    """Raises error if version  is not high enough"""
+def version(
+    requirement: str, current: str = __version__, package_name="gdsfactory"
+) -> None:
+    """Raises error if current version does not match requirement."""
 
-    if __version__ < version:
+    s = semantic_version.SimpleSpec(requirement)
+    if not s.match(semantic_version.Version(current)):
         raise ValueError(
-            f"gf.minimum required version = {version}\n"
-            f"not compatible your current installed version {__version__}\n"
+            f"{package_name} requirement {requirement}\n"
+            f"not compatible your current installed version {current}\n"
             "you can run:\n"
-            "pip install gf.--upgrade\n"
-            "to install a later version",
+            f"pip install {package_name} {requirement}\n"
         )
 
 
 if __name__ == "__main__":
-    # equal_or_greater_than("3.0.0")
-    # equal_or_greater_than("2.4.9")
-    # equal_or_greater_than("2.4.8")
-    version_equal_or_greater_than("2.5.0")
+    # version(">=3.8.10")
+    version("<=3.8.7")
