@@ -20,7 +20,6 @@ iso_lines_coarse1:
 """
 import collections
 import os
-import sys
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
@@ -30,19 +29,14 @@ from klayout.dbcore import Cell, CellInstArray, Layout
 from numpy import float64
 from omegaconf import OmegaConf
 
-import gdsfactory.autoplacer.text as text
+from gdsfactory.autoplacer import text
 from gdsfactory.autoplacer.helpers import CELLS, import_cell, load_gds
-from gdsfactory.config import CONFIG
+from gdsfactory.config import CONFIG, logger
 
 UM_TO_GRID = 1e3
 DEFAULT_BBOX_LAYER_IGNORE = [(8484, 8484)]
 
 
-def _print(*args, **kwargs):
-    print(*args, **kwargs)
-    sys.stdout.flush()
-
-
 def to_grid(x: float64, um_to_grid: int = UM_TO_GRID) -> int:
     return int(x * um_to_grid)
 
@@ -115,13 +109,13 @@ class SizeInfo:
 
 def placer_grid_cell_refs(
     cells,
-    cols=1,
-    rows=1,
-    dx=10.0,
-    dy=10.0,
-    x0=0,
-    y0=0,
-    um_to_grid=UM_TO_GRID,
+    cols: int = 1,
+    rows: int = 1,
+    dx: float = 10.0,
+    dy: float = 10.0,
+    x0: float = 0,
+    y0: float = 0,
+    um_to_grid: float = UM_TO_GRID,
     **settings,
 ):
     """cells: list of cells - order matters for placing"""
@@ -148,7 +142,7 @@ def placer_grid_cell_refs(
 def pack_row(
     cells: List[Cell],
     row_ids: Optional[List[int]] = None,
-    nb_cols: None = None,
+    nb_cols: Optional[int] = None,
     x0: Union[float, int] = 0,
     y0: Union[float, int] = 0,
     align_x: str = "W",
@@ -157,17 +151,17 @@ def pack_row(
     margin_x: Optional[Union[float, int]] = None,
     margin_y: Optional[Union[float, int]] = None,
     um_to_grid: int = UM_TO_GRID,
-    period_x: None = None,
-    period_y: None = None,
+    period_x: Optional[float] = None,
+    period_y: Optional[float] = None,
     rotation: int = 0,
 ) -> List[CellInstArray]:
     """Pack row.
     Args:
-        cells: a list of cells  (size n)
+        cells: a list of cells (size n)
         row_ids: a list of row ids (size n)
             where each id represents the row where the cell should be placed
             None by default => all cells in the same row
-
+        nb_cols: number of columns
         period_x, period_y: not used by default,
             if set, use this period instead of computing the component spacing
             from the margin and the component dimension
@@ -194,9 +188,8 @@ def pack_row(
 
     if len(cells) != len(row_ids):
         raise ValueError(
-            "Each cell should be assigned a row id.         Got {} cells for {} row ids".format(
-                len(cells), len(row_ids)
-            )
+            "Each cell should be assigned a row id. "
+            f"Got {len(cells)} cells for {len(row_ids)} row ids"
         )
 
     # Find the height of each row to fit the cells
@@ -240,12 +233,12 @@ def pack_row(
                 components += [c_ref]
 
             except BaseException:
-                print(x, component_origin[0], um_to_grid)
-                print("ISSUE PLACING AT", _x, _y)
+                logger.error(x, component_origin[0], um_to_grid)
+                logger.error("ISSUE PLACING AT", _x, _y)
                 if align_x not in ["W", "E"]:
-                    _print("align_x should be `W`, `E` or a float")
+                    logger.error("align_x should be `W`, `E` or a float")
                 if align_y not in ["N", "S"]:
-                    _print("align_y should be `N`, `S` or a float")
+                    logger.error("align_y should be `N`, `S` or a float")
                 # raise
 
             dx = si.width + margin_x if period_x is None else period_x
@@ -267,7 +260,7 @@ def pack_row(
 def pack_col(
     cells: List[Cell],
     col_ids: None = None,
-    nb_rows: None = None,
+    nb_rows: Optional[int] = None,
     x0: float = 0,
     y0: float = 0,
     align_x: str = "W",
@@ -276,8 +269,8 @@ def pack_col(
     margin_x: Optional[int] = None,
     margin_y: Optional[int] = None,
     um_to_grid: int = UM_TO_GRID,
-    period_x: None = None,
-    period_y: None = None,
+    period_x: Optional[float] = None,
+    period_y: Optional[float] = None,
 ) -> List[CellInstArray]:
     """
 
@@ -309,9 +302,8 @@ def pack_col(
 
     if len(cells) != len(col_ids):
         raise ValueError(
-            "Each cell should be assigned a row id.         Got {} cells for {} col ids".format(
-                len(cells), len(col_ids)
-            )
+            "Each cell should be assigned a row id. "
+            f"Got {len(cells)} cells for {len(col_ids)} col ids"
         )
 
     # Find the width of each column to fit the cells
@@ -375,7 +367,14 @@ def pack_col(
 
 
 def placer_fixed_coords(
-    cells, x, y, x0=0, y0=0, do_permutation=False, um_to_grid=UM_TO_GRID, **kwargs
+    cells,
+    x,
+    y,
+    x0: float = 0,
+    y0: float = 0,
+    do_permutation: bool = False,
+    um_to_grid=UM_TO_GRID,
+    **kwargs,
 ):
     """place cells using a list of coordinates"""
 
@@ -448,16 +447,12 @@ def load_doe(doe_name: str, doe_root: Path) -> List[Layout]:
             line = lines[0]
 
             if line.startswith("TEMPLATE:"):
-                """
-                If using a template, load the GDS from DOE folder used as a template
-                """
+                # If using a template, load the GDS from DOE folder used as a template
                 template_name = line.split(":")[1].strip()
                 return load_doe(template_name, doe_root)
 
             else:
-                """
-                Otherwise load the GDS from the current folder
-                """
+                # Otherwise load the GDS from the current folder
                 component_names = line.split(" , ")
                 gdspaths = [
                     os.path.join(doe_dir, name + ".gds") for name in component_names
@@ -734,7 +729,7 @@ def place_from_yaml(
             placed_doe = doe_cell
             doe_instance = pya.CellInstArray(doe_cell.cell_index(), transform_identity)
         else:
-            # If only single cell and we want to skip the doe cell
+            # If only single cell and we want to skip the sweep cell
             doe_instance = placed_components[0]
             placed_does[doe_name] = doe_instance
             placed_doe = doe_instance
@@ -773,7 +768,7 @@ def place_and_write(
     filepath_yaml, root_does=CONFIG["cache_doe_directory"], filepath_gds="top_level.gds"
 ):
     c = place_from_yaml(filepath_yaml, root_does)
-    _print("writing...")
+    logger.info("writing...")
     c.write(filepath_gds)
 
 
