@@ -31,7 +31,7 @@ def coupler_straight(
     # bot.ymax = 0
     # top.ymin = gap
 
-    top.movey(straight_component.width + gap)
+    top.movey(straight_component.info.width + gap)
 
     component.add_port("o1", port=bot.ports["o1"])
     component.add_port("o2", port=top.ports["o1"])
