@@ -21,8 +21,8 @@ def loop_mirror(
     routes = route_manhattan(
         cref.ports["o3"],
         cref.ports["o2"],
-        straight_factory=gf.components.straight,
-        bend_factory=bend90,
+        straight=gf.components.straight,
+        bend=bend90,
     )
     c.add(routes.references)
     c.add_port(name="o1", port=cref.ports["o1"])
