@@ -27,7 +27,7 @@ def straight_array(
 
     for i in range(n):
         wref = c.add_ref(wg)
-        wref.y += i * (spacing + wg.width)
+        wref.y += i * (spacing + wg.info.width)
         c.add_ports(wref.ports, prefix=str(i))
 
     c.auto_rename_ports()
@@ -36,5 +36,5 @@ def straight_array(
 
 if __name__ == "__main__":
     c = straight_array()
-    c.pprint_ports
+    c.pprint_ports()
     c.show(show_ports=True)
