@@ -1,17 +1,17 @@
-"""gf.loads a configuration from 3 files, high priority overwrites low priority:
+"""gdsfactory loads a configuration from 3 files, high priority overwrites low priority:
 
 1. A config.yml found in the current working directory (highest priority)
-2. ~/.gf.config.yml specific for the machine
-3. the yamlpath_default in gf.tech.yml (lowest priority)
+2. ~/.gdsfactory/config.yml specific for the machine
+3. the yamlpath_default in gdsfactory.tech.yml (lowest priority)
 
 `CONFIG` has all your computer specific paths that we do not care to store
-`TECH` has all the useful info that we will store to have reproduceable layouts.
+`TECH` has all the useful info that we will store to have reproducible layouts.
 
-You can access all the config dictionary with `print_config` as well as a particular key
+You can access the config dictionary with `print_config`
 
 """
 
-__version__ = "3.1.4"
+__version__ = "3.9.8"
 import json
 import os
 import pathlib
@@ -52,6 +52,16 @@ logger.info(__version__)
 logger.add(sink=logpath)
 
 
+class Paths:
+    module = module_path
+    repo = repo_path
+    sparameters = repo_path / "sparameters"
+    results_tidy3d = home / ".tidy3d"
+    klayout = module / "klayout"
+    klayout_tech = klayout / "tech"
+    klayout_lyp = klayout_tech / "layers.lyp"
+
+
 def read_config(
     yamlpaths: Iterable[PathType] = (yamlpath_default, yamlpath_home, yamlpath_cwd),
 ) -> omegaconf.DictConfig:
@@ -65,6 +75,7 @@ def read_config(
 
 
 CONF = read_config()
+PATH = Paths()
 
 
 CONFIG = dict(
@@ -95,14 +106,13 @@ else:
 
 # CONFIG["custom_components"] = TECH.custom_components
 CONFIG["gdslib"] = repo_path / "gdslib"
-CONFIG["sp"] = CONFIG["gdslib"] / "sp"
-CONFIG["gds"] = CONFIG["gdslib"] / "gds"
-CONFIG["gdslib_test"] = dirpath_test
+CONFIG["sparameters"] = CONFIG["gdslib"] / "sp"
 
 CONFIG["build_directory"] = build_directory
 CONFIG["gds_directory"] = build_directory / "devices"
+CONFIG["cache_directory"] = CONF.get("cache", build_directory / "cache")
 CONFIG["cache_doe_directory"] = build_directory / "cache_doe"
-CONFIG["doe_directory"] = build_directory / "doe"
+CONFIG["doe_directory"] = build_directory / "sweep"
 CONFIG["mask_directory"] = build_directory / "mask"
 CONFIG["mask_gds"] = build_directory / "mask" / (mask_name + ".gds")
 CONFIG["mask_config_directory"] = mask_config_directory
@@ -117,7 +127,6 @@ build_directory.mkdir(exist_ok=True)
 CONFIG["gds_directory"].mkdir(exist_ok=True)
 CONFIG["doe_directory"].mkdir(exist_ok=True)
 CONFIG["mask_directory"].mkdir(exist_ok=True)
-CONFIG["gdslib_test"].mkdir(exist_ok=True)
 
 
 def print_config(key: Optional[str] = None) -> None:
@@ -199,7 +208,7 @@ if __name__ == "__main__":
     # print(TECH)
     # print_config("gdslib")
     # print(CONFIG["git_hash"])
-    # print(CONFIG["sp"])
-    # print(CONFIG)
+    # print(CONFIG["sparameters"])
+    print(CONFIG)
     # print_config()
-    write_tech("tech.json")
+    # write_tech("tech.json")
