@@ -10,7 +10,9 @@ from pathlib import Path
 from typing import Union
 
 
-def show(gds_filename: Union[Path, str], keep_position: bool = True) -> None:
+def show(
+    gds_filename: Union[Path, str], keep_position: bool = True, port: int = 8082
+) -> None:
     """Show GDS in klayout."""
     if not os.path.isfile(gds_filename):
         raise ValueError(f"{gds_filename} does not exist")
@@ -20,7 +22,7 @@ def show(gds_filename: Union[Path, str], keep_position: bool = True) -> None:
     }
     data_string = json.dumps(data)
     try:
-        conn = socket.create_connection(("127.0.0.1", 8082), timeout=1.0)
+        conn = socket.create_connection(("127.0.0.1", port), timeout=1.0)
         data_string = data_string + "\n"
         data_string = (
             data_string.encode() if hasattr(data_string, "encode") else data_string
