@@ -11,7 +11,7 @@ from gdsfactory.mask.write_labels import write_labels
 def merge_metadata(
     gdspath: Path,
     labels_prefix: str = "opt",
-    label_layer: Tuple[int, int] = gf.LAYER.LABEL,
+    label_layer: Tuple[int, int] = gf.LAYER.TEXT,
     **kwargs
 ) -> None:
     """Merges all JSON metadata into a big JSON.
@@ -25,7 +25,7 @@ def merge_metadata(
     jsonpath = gdspath.with_suffix(".json")
 
     build_directory = gdspath.parent.parent
-    doe_directory = build_directory / "doe"
+    doe_directory = build_directory / "sweep"
 
     write_labels(gdspath=gdspath, prefix=labels_prefix, label_layer=label_layer)
 
