@@ -2,16 +2,30 @@
 """
 import functools
 import hashlib
-from typing import Any
+import inspect
+from typing import Any, Iterable
 
 import numpy as np
-from phidl import Device
+import pydantic
+import toolz
+from phidl import Device, Port
+from phidl.device_layout import Path as PathPhidl
 
+from gdsfactory.hash_points import hash_points
 from gdsfactory.snap import snap_to_grid
 
 MAX_NAME_LENGTH = 32
 
 
+@pydantic.validate_arguments
+def get_name_short(name: str, max_name_length=MAX_NAME_LENGTH) -> str:
+    """Returns a short name."""
+    if len(name) > max_name_length:
+        name_hash = hashlib.md5(name.encode()).hexdigest()[:8]
+        name = f"{name[:(max_name_length - 9)]}_{name_hash}"
+    return name
+
+
 def join_first_letters(name: str) -> str:
     """Join the first letter of a name separated with underscores.
 
@@ -115,6 +129,7 @@ def clean_name(name: str) -> str:
         "@": "_",
         "[": "",
         "]": "",
+        "$": "",
     }
     for k, v in list(replace_map.items()):
         name = name.replace(k, v)
@@ -134,7 +149,7 @@ def clean_value(value: Any) -> str:
     elif isinstance(value, (float, np.float64)):
         if 1 > value > 1e-3:
             value = f"{int(value*1e3)}n"
-        elif float(int(value)) == value:
+        elif int(value) == value:
             value = str(int(value))
         elif 1e-6 < value < 1e-3:
             value = f"{snap_to_grid(value*1e6)}u"
@@ -142,49 +157,44 @@ def clean_value(value: Any) -> str:
             value = f"{snap_to_grid(value*1e9)}n"
         elif 1e-12 < value < 1e-9:
             value = f"{snap_to_grid(value*1e12)}p"
-        else:
+        else:  # Any unit < 1pm will disappear
             value = str(snap_to_grid(value)).replace(".", "p")
-    elif isinstance(value, list):
-        value = "_".join(clean_value(v) for v in value)
-    elif isinstance(value, tuple):
-        value = "_".join(clean_value(v) for v in value)
+    elif isinstance(value, Device):
+        value = clean_name(value.name)
+    elif isinstance(value, str):
+        value = value.strip()
     elif isinstance(value, dict):
         value = dict2name(**value)
         # value = [f"{k}={v!r}" for k, v in value.items()]
-    elif isinstance(value, Device):
-        value = clean_name(value.name)
+    elif isinstance(value, Port):
+        value = f"{value.name}_{value.width}_{value.x}_{value.y}"
+    elif isinstance(value, PathPhidl):
+        value = f"path_{hash_points(value.points)}"
     elif (
         isinstance(value, object)
         and hasattr(value, "name")
         and isinstance(value.name, str)
     ):
         value = clean_name(value.name)
+    elif callable(value) and isinstance(value, functools.partial):
+        sig = inspect.signature(value.func)
+        args_as_kwargs = dict(zip(sig.parameters.keys(), value.args))
+        args_as_kwargs.update(**value.keywords)
+        value = value.func.__name__ + dict2name(**args_as_kwargs)
+    elif callable(value) and isinstance(value, toolz.functoolz.Compose):
+        value = "_".join(
+            [clean_value(v) for v in value.funcs] + [clean_value(value.first)]
+        )
     elif callable(value) and hasattr(value, "__name__"):
         value = value.__name__
-    elif callable(value) and isinstance(value, functools.partial):
-        value = value.func.__name__ + dict2name(**value.keywords)
-    elif isinstance(value, str):
-        value = value.strip()
+    elif hasattr(value, "get_name"):
+        value = value.get_name()
+    elif isinstance(value, Iterable):
+        value = "_".join(clean_value(v) for v in value)
+
     return str(value)
 
 
-def get_name_short(name: str):
-    if len(name) > MAX_NAME_LENGTH:
-        name_hash = hashlib.md5(name.encode()).hexdigest()[:8]
-        name = f"{name[:(MAX_NAME_LENGTH - 9)]}_{name_hash}"
-    return clean_name(name)
-
-
-def get_name(name: str) -> str:
-    """Returns name with correct number of characters"""
-    if not isinstance(name, str):
-        raise ValueError(f"{name} needs to be a string")
-    if len(name) > MAX_NAME_LENGTH:
-        name_hash = hashlib.md5(name.encode()).hexdigest()[:8]
-        name = f"{name[:(MAX_NAME_LENGTH - 9)]}_{name_hash}"
-    return clean_name(name)
-
-
 def test_clean_value() -> None:
     assert clean_value(0.5) == "500n"
     assert clean_value(5) == "5"
@@ -198,11 +208,12 @@ def test_clean_name() -> None:
 
 if __name__ == "__main__":
     # test_cell()
+    test_clean_value()
     import gdsfactory as gf
 
     # print(clean_value(gf.components.straight))
     # c = gf.components.straight(polarization="TMeraer")
-    # print(c.get_settings()["polarization"])
+    # print(c.settings["polarization"])
     # print(clean_value(11.001))
     # layers_cladding = (gf.LAYER.WGCLAD, gf.LAYER.NO_TILE_SI)
     # layers_cladding = (gf.LAYER.WGCLAD,)
