@@ -2,13 +2,22 @@
 adapted from phidl.geometry.
 """
 
-from typing import Any, Dict, List, Tuple, Union
+import warnings
+from typing import Any, Dict, List, Optional, Tuple
 
 import numpy as np
 import rectpack
+from pydantic import validate_arguments
 
 from gdsfactory.component import Component
-from gdsfactory.types import Coordinate, Number
+from gdsfactory.name import get_name_short
+from gdsfactory.types import (
+    Anchor,
+    ComponentFactory,
+    ComponentOrFactory,
+    Float2,
+    Number,
+)
 
 
 def _pack_single_bin(
@@ -17,7 +26,6 @@ def _pack_single_bin(
     max_size: Tuple[float, float],
     sort_by_area: bool,
     density: float,
-    precision: float,
 ) -> Tuple[Dict[int, Tuple[Number, Number, Number, Number]], Dict[Any, Any]]:
     """Packs a dict of rectangles {id:(w,h)} and tries to
     pack it into a bin as small as possible with aspect ratio `aspect_ratio`
@@ -29,8 +37,7 @@ def _pack_single_bin(
         aspect_ratio:
         max_size: tuple of max X, Y size
         sort_by_area: sorts components by area
-        density: of packing. Values closer to 1 require more computation to pack tighter
-        precision: Desired precision for rounding vertex coordinates.
+        density: of packing, closer to 1 packs tighter (more compute heavy)
 
     Returns:
         packed rectangles dict {id:(x,y,w,h)}
@@ -86,35 +93,53 @@ def _pack_single_bin(
         if k not in packed_rect_dict:
             unpacked_rect_dict[k] = v
 
-    return (packed_rect_dict, unpacked_rect_dict)
+    return packed_rect_dict, unpacked_rect_dict
 
 
+@validate_arguments
 def pack(
-    component_list: List[Component],
+    component_list: List[ComponentOrFactory],
     spacing: float = 10.0,
-    aspect_ratio: Tuple[Number, Number] = (1, 1),
-    max_size: Union[Coordinate, Tuple[None, None]] = (None, None),
+    aspect_ratio: Float2 = (1.0, 1.0),
+    max_size: Tuple[Optional[float], Optional[float]] = (None, None),
     sort_by_area: bool = True,
     density: float = 1.1,
     precision: float = 1e-2,
+    text: Optional[ComponentFactory] = None,
+    text_prefix: str = "",
+    text_offsets: Tuple[Float2, ...] = ((0, 0),),
+    text_anchors: Tuple[Anchor, ...] = ("cc",),
+    name_prefix: Optional[str] = None,
+    rotation: int = 0,
+    h_mirror: bool = False,
+    v_mirror: bool = False,
 ) -> List[Component]:
     """Pack a list of components into as few Components as possible.
+
     Adapted from phidl.geometry
 
     Args:
-        component_list: Must be a list or tuple of Components
+        component_list: list or tuple
         spacing: Minimum distance between adjacent shapes
         aspect_ratio: (width, height) ratio of the rectangular bin
         max_size: Limits the size into which the shapes will be packed
         sort_by_area: Pre-sorts the shapes by area
         density: Values closer to 1 pack tighter but require more computation
         precision: Desired precision for rounding vertex coordinates.
+        text: Optional function to add text labels.
+        text_prefix: for labels. For example. 'A' will produce 'A1', 'A2', ...
+        text_offsets: relative to component size info anchor. Defaults to center.
+        text_anchors: relative to component (ce cw nc ne nw sc se sw center cc).
+        name_prefix: for each packed component (avoids the Unnamed cells warning).
+            Note that the suffix contains a uuid so the name will not be deterministic
+        rotation: for each component in degrees
+        h_mirror: horizontal mirror in y axis (x, 1) (1, 0). This is the most common.
+        v_mirror: vertical mirror using x axis (1, y) (0, y)
     """
-
     if density < 1.01:
         raise ValueError(
-            "pack() was given a `density` argument that is"
-            + " too small.  The density argument must be >= 1.01"
+            "pack() `density` argument is too small. "
+            "The density argument must be >= 1.01"
         )
 
     # Santize max_size variable
@@ -122,6 +147,11 @@ def pack(
     max_size = np.asarray(max_size, dtype=np.float64)  # In case it's integers
     max_size = max_size / precision
 
+    component_list = [
+        component() if callable(component) else component
+        for component in component_list
+    ]
+
     # Convert Components to rectangles
     rect_dict = {}
     for n, D in enumerate(component_list):
@@ -129,9 +159,9 @@ def pack(
         w, h = int(w), int(h)
         if (w > max_size[0]) or (h > max_size[1]):
             raise ValueError(
-                "pack() failed because one of the objects (D)"
-                + "in `component_list` is has an x or y dimension larger than `max_size` and "
-                + "so cannot be packed"
+                f"pack() failed because Component {D.name!r} has x or y "
+                "dimension larger than `max_size` and cannot be packed.\n"
+                f"size = {w*precision, h*precision}, max_size = {max_size*precision}"
             )
         rect_dict[n] = (w, h)
 
@@ -143,33 +173,52 @@ def pack(
             max_size=max_size,
             sort_by_area=sort_by_area,
             density=density,
-            precision=precision,
         )
         packed_list.append(packed_rect_dict)
 
     components_packed_list = []
-    for rect_dict in packed_list:
-        packed = Component()
-        packed.settings["components"] = {}
+    index = 0
+    for i, rect_dict in enumerate(packed_list):
+        name = get_name_short(f"{name_prefix or 'pack'}_{i}")
+        packed = Component(name, with_uuid=True)
+        packed.info["components"] = {}
         for n, rect in rect_dict.items():
             x, y, w, h = rect
             xcenter = x + w / 2 + spacing / 2
             ycenter = y + h / 2 + spacing / 2
             component = component_list[n]
-            d = packed.add_ref(component)
+            d = component.ref(rotation=rotation, h_mirror=h_mirror, v_mirror=v_mirror)
+            packed.add(d)
             if hasattr(component, "settings"):
-                packed.settings["components"][component.name] = component.get_settings()
+                packed.info["components"][component.name] = component.settings
             d.center = (xcenter * precision, ycenter * precision)
+
+            if text:
+                for text_offset, text_anchor in zip(text_offsets, text_anchors):
+                    label = packed << text(f"{text_prefix}{index}")
+                    label.move(
+                        (np.array(text_offset) + getattr(d.size_info, text_anchor))
+                    )
+                index += 1
+
         components_packed_list.append(packed)
 
+    if len(components_packed_list) > 1:
+        groups = len(components_packed_list)
+        warnings.warn(f"unable to pack in one component, creating {groups} components")
+
     return components_packed_list
 
 
 def test_pack() -> Component:
-    import phidl.geometry as pg
+    import gdsfactory as gf
 
-    component_list = [pg.ellipse(radii=np.random.rand(2) * n + 2) for n in range(2)]
-    component_list += [pg.rectangle(size=np.random.rand(2) * n + 2) for n in range(2)]
+    component_list = [
+        gf.components.ellipse(radii=tuple(np.random.rand(2) * n + 2)) for n in range(2)
+    ]
+    component_list += [
+        gf.components.rectangle(size=tuple(np.random.rand(2) * n + 2)) for n in range(2)
+    ]
 
     components_packed_list = pack(
         component_list,  # Must be a list or tuple of Components
@@ -180,7 +229,6 @@ def test_pack() -> Component:
         sort_by_area=True,  # Pre-sorts the shapes by area
     )
     c = components_packed_list[0]  # Only one bin was created, so we plot that
-    # print(len(c.get_dependencies()))
     assert len(c.get_dependencies()) == 4
     return c
 
@@ -188,42 +236,49 @@ def test_pack() -> Component:
 def test_pack_with_settings() -> Component:
     import gdsfactory as gf
 
-    component_list = [gf.components.rectangle(size=(i, i)) for i in range(1, 10)]
-    component_list += [gf.components.rectangle(size=(i, i)) for i in range(1, 10)]
+    component_list = [
+        gf.components.rectangle(size=(i, i), port_type=None) for i in range(1, 10)
+    ]
+    component_list += [
+        gf.components.rectangle(size=(i, i), port_type=None) for i in range(1, 10)
+    ]
 
     components_packed_list = pack(
         component_list,  # Must be a list or tuple of Components
         spacing=1.25,  # Minimum distance between adjacent shapes
         aspect_ratio=(2, 1),  # (width, height) ratio of the rectangular bin
-        max_size=(None, None),  # Limits the size into which the shapes will be packed
+        # max_size=(None, None),  # Limits the size into which the shapes will be packed
+        max_size=(20, 20),  # Limits the size into which the shapes will be packed
         density=1.05,  # Values closer to 1 pack tighter but require more computation
         sort_by_area=True,  # Pre-sorts the shapes by area
         precision=1e-3,
     )
-    c = components_packed_list[0]  # Only one bin was created, so we plot that
+    c = components_packed_list[0]
     # print(len(c.get_dependencies()))
     return c
 
 
 if __name__ == "__main__":
+    # test_pack()
+    import gdsfactory as gf
 
-    c = test_pack_with_settings()
+    # c = test_pack_with_settings()
     # c = test_pack()
-    c.show()
-    c.pprint
-    c.write_gds_with_metadata("mask.gds")
+    # c.show()
+    # c.pprint()
+    # c.write_gds_with_metadata("mask.gds")
 
-    # import phidl.geometry as pg
-    # spacing = 1
-    # ellipses = pack(
-    #     [pg.ellipse(radii=np.random.rand(2) * n + 2) for n in range(50)],
-    #     spacing=spacing,
-    # )[0]
-    # ellipses.name = "ellipses"
-    # rectangles = pack(
-    #     [pg.rectangle(size=np.random.rand(2) * n + 2) for n in range(50)],
-    #     spacing=spacing,
-    # )[0]
-    # rectangles.name = "rectangles"
-    # p = pack([ellipses, rectangles])
-    # p.show()
+    p = pack(
+        [gf.components.triangle(x=i) for i in range(1, 10)],
+        spacing=20.0,
+        max_size=(100, 100),
+        text=gf.partial(gf.c.text, justify="center"),
+        text_prefix="R",
+        name_prefix="demo",
+        text_anchor="nc",
+        text_offset=(-10, 0),
+        v_mirror=True,
+    )
+    c = p[0]
+    print(c.name)
+    c.show()
