@@ -32,7 +32,6 @@ YAML defines component DOE settings and placement
 
 import os
 import pathlib
-import sys
 from pathlib import Path
 from typing import Callable, Dict, List, Union
 
@@ -41,16 +40,11 @@ from omegaconf import OmegaConf
 import gdsfactory as gf
 from gdsfactory.component import Component, ComponentReference
 from gdsfactory.components import factory
-from gdsfactory.config import CONFIG
-from gdsfactory.doe import get_settings_list, load_does
+from gdsfactory.config import CONFIG, logger
+from gdsfactory.sweep.read_sweep import get_settings_list, read_sweep
 from gdsfactory.types import ComponentFactoryDict
 
 
-def _print(*args, **kwargs):
-    print(*args, **kwargs)
-    sys.stdout.flush()
-
-
 def placer_grid_cell_refs(
     component_factory: ComponentFactoryDict = factory,
     cols: int = 1,
@@ -190,10 +184,8 @@ def pack_vertical(
 
     if len(cells) != len(col_ids):
         raise ValueError(
-            "Each cell should be assigned a row id. \
-        Got {} cells for {} col ids".format(
-                len(cells), len(col_ids)
-            )
+            "Each cell should be assigned a row id. "
+            f"Got {len(cells)} cells for {len(col_ids)} col ids"
         )
 
     # Find the width of each column to fit the cells
@@ -300,10 +292,10 @@ def load_placer_with_does(filepath, defaults=None):
             settings = {}
         doe["list_settings"] += get_settings_list(do_permutation, **settings)
 
-        # check that the doe is valid (only one type of component)
+        # check that the sweep is valid (only one type of component)
         assert (
             component_type == doe["component_type"]
-        ), "There can be only one component type per doe. Got {} while expecting {}".format(
+        ), "There can be only one component type per sweep. Got {} while expecting {}".format(
             component_type, doe["component_type"]
         )
 
@@ -368,12 +360,19 @@ def doe_exists(
     """
     Check whether the folder exists and that the number of items in content.txt
     matches the number of items in list_settings
+
+    Args:
+        doe_name: name of the doe
+        list_settings:
+        doe_root_path: path
     """
-    if doe_root_path is None:
-        doe_root_path = CONFIG["cache_doe_directory"]
-    doe_dir = os.path.join(doe_root_path, doe_name)
-    content_file = os.path.join(doe_dir, "content.txt")
-    if not os.path.exists(content_file):
+    doe_root_path = doe_root_path or CONFIG["cache_doe_directory"]
+    doe_root_path = Path(doe_root_path)
+    doe_dir = doe_root_path / doe_name
+    content_file = doe_dir / "content.txt"
+
+    if not content_file.exists():
+        print(f"{content_file} not found")
         return False
     with open(content_file) as f:
         component_names = f.read().split(CONTENT_SEP)
@@ -381,6 +380,7 @@ def doe_exists(
     if len(component_names) == len(list_settings) or (
         len(list_settings) == 0 and len(component_names) == 1
     ):
+        print(f"{content_file} found")
         return True
 
     print(
@@ -399,7 +399,7 @@ def component_grid_from_yaml(filepath: Path, precision: float = 1e-9) -> Compone
     """
     input_does = OmegaConf.load(str(filepath))
     mask_settings = input_does["mask"]
-    does = load_does(filepath)
+    does = read_sweep(filepath)
 
     placed_doe = None
     placed_does = {}
@@ -415,9 +415,9 @@ def component_grid_from_yaml(filepath: Path, precision: float = 1e-9) -> Compone
         list_settings = doe["settings"]
         component_type = doe["component"]
 
-        # description = doe["description"] if "description" in doe else ''
-        # test = doe["test"] if "test" in doe else {}
-        # analysis = doe["analysis"] if "analysis" in doe else {}
+        # description = sweep["description"] if "description" in sweep else ''
+        # test = sweep["test"] if "test" in sweep else {}
+        # analysis = sweep["analysis"] if "analysis" in sweep else {}
 
         # Get DOE policy concerning the cache
         cache_enabled = (
@@ -431,7 +431,7 @@ def component_grid_from_yaml(filepath: Path, precision: float = 1e-9) -> Compone
             try:
                 components = load_doe_from_cache(doe_name)
             except Exception as e:
-                _print(e)
+                logger.error(e)
                 components = None
 
         # If no component is loaded, build them
@@ -443,9 +443,9 @@ def component_grid_from_yaml(filepath: Path, precision: float = 1e-9) -> Compone
             if cache_enabled:
                 save_doe(doe_name, components, precision=precision)
         else:
-            _print("{} - Loaded components from cache".format(doe_name))
+            logger.info("{} - Loaded components from cache".format(doe_name))
 
-        # _print(doe_name, [c.name for c in components])
+        # logger.info(doe_name, [c.name for c in components])
         # Find placer information
 
         default_settings = {"align_x": "W", "align_y": "S", "margin": 10}
