@@ -67,7 +67,7 @@ class Port(PortPhidl):
         orientation: in degrees (0: east, 90: north, 180: west, 270: south)
         parent: parent component (component to which this port belong to)
         layer: (1, 0)
-        port_type: str
+        port_type: str (optical, electrical, vertical_te, vertical_tm)
 
     """
 
@@ -82,6 +82,7 @@ class Port(PortPhidl):
         layer: Tuple[int, int] = (1, 0),
         port_type: str = "optical",
         parent: Optional[object] = None,
+        cross_section: Optional[object] = None,
     ) -> None:
         self.name = name
         self.midpoint = np.array(midpoint, dtype="float64")
@@ -92,6 +93,7 @@ class Port(PortPhidl):
         self.uid = Port._next_uid
         self.layer = layer
         self.port_type = port_type
+        self.cross_section = cross_section
 
         if self.width < 0:
             raise ValueError("[PHIDL] Port creation error: width must be >=0")
@@ -106,11 +108,13 @@ class Port(PortPhidl):
 
     @classmethod
     def validate(cls, v):
-        """For pydantic assumes Port is valid if:
+        """For pydantic assumes Port is valid if has a name and a valid type
+
         - has a name
         """
         assert v.name, f"Port has no name, got `{v.name}`"
         # assert v.assert_on_grid(), f"port.midpoint = {v.midpoint} has off-grid points"
+        assert isinstance(v, Port), f"TypeError, Got {type(v)}, expecting Port"
         return v
 
     @property
@@ -119,7 +123,7 @@ class Port(PortPhidl):
             name=self.name,
             midpoint=self.midpoint,
             width=self.width,
-            orientation=self.orientation,
+            orientation=float(self.orientation),
             layer=self.layer,
             port_type=self.port_type,
         )
@@ -145,7 +149,7 @@ class Port(PortPhidl):
         self.midpoint = self.midpoint + np.array(vector)
 
     def move_polar_copy(self, d, angle) -> PortPhidl:
-        port = self._copy()
+        port = self.copy()
         DEG2RAD = np.pi / 180
         dp = np.array((d * np.cos(DEG2RAD * angle), d * np.sin(DEG2RAD * angle)))
         self.move(dp)
@@ -153,11 +157,15 @@ class Port(PortPhidl):
 
     def flip(self):
         """flips port"""
-        port = self._copy()
+        port = self.copy()
         port.angle = (port.angle + 180) % 360
         return port
 
     def _copy(self, new_uid: bool = True) -> PortPhidl:
+        """Keep this case for phidl compatibility"""
+        return self.copy(new_uid=new_uid)
+
+    def copy(self, new_uid: bool = True) -> PortPhidl:
         new_port = Port(
             name=self.name,
             midpoint=self.midpoint,
@@ -166,6 +174,7 @@ class Port(PortPhidl):
             parent=self.parent,
             layer=self.layer,
             port_type=self.port_type,
+            cross_section=self.cross_section,
         )
         new_port.info = deepcopy(self.info)
         if not new_uid:
@@ -187,7 +196,7 @@ class Port(PortPhidl):
         """Ensures ports edges are on grid to avoid snap_to_grid errors."""
         half_width = self.width / 2
         half_width_correct = snap_to_grid(half_width, nm=nm)
-        component_name = self.parent.get_property("name")
+        component_name = self.parent.name
         if not np.isclose(half_width, half_width_correct):
             raise PortNotOnGridError(
                 f"{component_name}, port = {self.name}, midpoint = {self.midpoint} width = {self.width} will create off-grid points",
@@ -226,7 +235,7 @@ def port_array(
     n: int = 2,
     **kwargs,
 ) -> List[Port]:
-    """returns a list of ports placed in an array
+    """Returns a list of ports placed in an array
 
     Args:
         midpoint: center point of the port
@@ -251,7 +260,7 @@ def port_array(
 def read_port_markers(
     component: object, layers: Tuple[Tuple[int, int], ...] = ((1, 10),)
 ) -> Device:
-    """loads a GDS and returns the extracted ports from layer markers
+    """Loads a GDS and returns the extracted ports from layer markers
 
     Args:
         component: or Component
@@ -367,14 +376,16 @@ def select_ports(
     port_type: Optional[str] = None,
     clockwise: bool = True,
 ) -> Dict[str, Port]:
-    """
+    """Returns a dict of ports from a dict of ports
+
     Args:
-        ports: Dict[str, Port] a port dictionnary {port name: port} (as returned by Component.ports)
-        layer: GDS layer
+        ports: Dict[str, Port] a port dict {port name: port}
+        layer: port GDS layer
         prefix: with in port name
-        orientation:
+        orientation: in degrees
         width:
         layers_excluded: List of layers to exclude
+        port_type: optical, electrical, ...
         clockwise: if True, sort ports clockwise, False: counter-clockwise
 
     Returns:
@@ -424,13 +435,13 @@ def select_ports_list(**kwargs) -> List[Port]:
 
 
 def flipped(port: Port) -> Port:
-    _port = port._copy()
+    _port = port.copy()
     _port.orientation = (_port.orientation + 180) % 360
     return _port
 
 
 def move_copy(port, x=0, y=0):
-    _port = port._copy()
+    _port = port.copy()
     _port.midpoint += (x, y)
     return _port
 
@@ -534,6 +545,28 @@ def _rename_ports_counter_clockwise(direction_ports, prefix=""):
 
 
 def _rename_ports_clockwise(direction_ports, prefix: str = ""):
+    """Rename ports in the clockwise direction starting from the bottom left (west) corner."""
+    east_ports = direction_ports["E"]
+    east_ports.sort(key=lambda p: -p.y)  # sort north to south
+
+    north_ports = direction_ports["N"]
+    north_ports.sort(key=lambda p: +p.x)  # sort west to east
+
+    west_ports = direction_ports["W"]
+    west_ports.sort(key=lambda p: +p.y)  # sort south to north
+
+    south_ports = direction_ports["S"]
+    south_ports.sort(key=lambda p: -p.x)  # sort east to west
+    # south_ports.sort(key=lambda p: p.y)  #  south first
+
+    ports = west_ports + north_ports + east_ports + south_ports
+
+    for i, p in enumerate(ports):
+        p.name = f"{prefix}{i+1}" if prefix else i + 1
+
+
+def _rename_ports_clockwise_top_right(direction_ports, prefix: str = ""):
+    """Rename ports in the clockwise direction starting from the top right corner."""
     east_ports = direction_ports["E"]
     east_ports.sort(key=lambda p: -p.y)  # sort north to south
 
@@ -546,7 +579,7 @@ def _rename_ports_clockwise(direction_ports, prefix: str = ""):
     south_ports = direction_ports["S"]
     south_ports.sort(key=lambda p: -p.x)  # sort east to west
 
-    ports = west_ports + north_ports + east_ports + south_ports
+    ports = east_ports + south_ports + west_ports + north_ports
 
     for i, p in enumerate(ports):
         p.name = f"{prefix}{i+1}" if prefix else i + 1
@@ -558,9 +591,16 @@ def rename_ports_by_orientation(
     select_ports: Optional[Callable] = None,
     function=_rename_ports_facing_side,
     prefix: str = "o",
-) -> None:
+) -> Device:
     """Returns Component with port names based on port orientation (E, N, W, S)
 
+    Args:
+        component:
+        layers_excluded:
+        select_ports:
+        function: to rename ports
+        prefix: to add on each port name
+
     .. code::
 
              N0  N1
@@ -597,6 +637,7 @@ def rename_ports_by_orientation(
 
     function(direction_ports, prefix=prefix)
     component.ports = {p.name: p for p in component.ports.values()}
+    return component
 
 
 def auto_rename_ports(
@@ -607,8 +648,17 @@ def auto_rename_ports(
     prefix_optical: str = "o",
     prefix_electrical: str = "e",
     **kwargs,
-):
-    """Adds prefix for optical and electical"""
+) -> Device:
+    """Adds prefix for optical and electical.
+
+    Args:
+        component:
+        function: to rename ports
+        select_ports_optical:
+        select_ports_electrical:
+        prefix_optical:
+        prefix_electrical:
+    """
     rename_ports_by_orientation(
         component=component,
         select_ports=select_ports_optical,
@@ -623,6 +673,7 @@ def auto_rename_ports(
         function=function,
         **kwargs,
     )
+    return component
 
 
 auto_rename_ports_counter_clockwise = partial(
@@ -655,7 +706,7 @@ def map_ports_layer_to_orientation(
     layers = {port.layer for port in ports.values()}
 
     for layer in layers:
-        ports_on_layer = [p._copy() for p in ports.values() if p.layer == layer]
+        ports_on_layer = [p.copy() for p in ports.values() if p.layer == layer]
 
         for p in ports_on_layer:
             p.name_original = p.name
@@ -695,7 +746,7 @@ def map_ports_to_orientation_cw(
     direction_ports = {x: [] for x in ["E", "N", "W", "S"]}
 
     ports = select_ports(ports, **kwargs)
-    ports_on_layer = [p._copy() for p in ports.values()]
+    ports_on_layer = [p.copy() for p in ports.values()]
 
     for p in ports_on_layer:
         p.name_original = p.name
@@ -793,7 +844,6 @@ if __name__ == "__main__":
     # m = map_ports_layer_to_orientation(c.ports)
     # pprint(m)
     # c.show()
-    # p0 = c.port_by_orientation_cw("E0", width=0.5)
     # print(p0)
     p0 = c.get_ports_list(orientation=90, clockwise=False)[0]
     print(p0)
