@@ -4,21 +4,26 @@ import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.bend_euler import bend_euler
 from gdsfactory.components.grating_coupler_elliptical_trenches import grating_coupler_te
-from gdsfactory.components.straight import straight
+from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.cross_section import strip
 from gdsfactory.port import select_ports_optical
 from gdsfactory.routing.get_input_labels import get_input_labels
 from gdsfactory.routing.route_fiber_array import route_fiber_array
 from gdsfactory.routing.sort_ports import sort_ports_x
-from gdsfactory.types import ComponentFactory, CrossSectionFactory
+from gdsfactory.types import (
+    ComponentFactory,
+    ComponentOrFactory,
+    ComponentOrFactoryOrList,
+    CrossSectionFactory,
+)
 
 
-@gf.cell_without_validator
+@gf.cell
 def add_fiber_array(
-    component: Component,
-    grating_coupler: Component = grating_coupler_te,
-    straight_factory: ComponentFactory = straight,
-    bend_factory: ComponentFactory = bend_euler,
+    component: ComponentOrFactory,
+    grating_coupler: ComponentOrFactoryOrList = grating_coupler_te,
+    straight: ComponentFactory = straight_function,
+    bend: ComponentFactory = bend_euler,
     gc_port_name: str = "o1",
     gc_port_labels: Optional[Tuple[str, ...]] = None,
     component_name: Optional[str] = None,
@@ -33,14 +38,18 @@ def add_fiber_array(
     Args:
         component: to connect
         grating_coupler: grating coupler instance, function or list of functions
-        bend_factory: bend_circular
+        straight: factory
+        bend: bend_circular
         gc_port_name: grating coupler input port name 'W0'
+        gc_port_labels: grating coupler list of labels
         component_name: for the label
+        select_ports: function to select ports
+        cross_section: cross_section function
         taper: taper function name or dict
         get_input_labels_function: function to get input labels for grating couplers
         get_input_label_text_loopback_function: function to get input label test
         get_input_label_text_function
-        straight_factory: straight
+        straight: straight
         fanout_length: None  # if None, automatic calculation of fanout length
         max_y0_optical: None
         with_loopback: True, adds loopback structures
@@ -61,7 +70,6 @@ def add_fiber_array(
     .. plot::
         :include-source:
 
-
         import gdsfactory as gf
         gf.config.set_plot_options(show_subports=False)
 
@@ -92,7 +100,7 @@ def add_fiber_array(
     if gc_port_name not in gc.ports:
         raise ValueError(f"gc_port_name={gc_port_name} not in {gc.ports.keys()}")
 
-    component_name = component_name or component.name
+    component_name = component_name or component.info_child.get("name", component.name)
     component_new = Component()
     component_new.component = component
 
@@ -104,8 +112,8 @@ def add_fiber_array(
     elements, io_gratings_lines, ports = route_fiber_array(
         component=component,
         grating_coupler=grating_coupler,
-        bend_factory=bend_factory,
-        straight_factory=straight_factory,
+        bend=bend,
+        straight=straight,
         gc_port_name=gc_port_name,
         component_name=component_name,
         cross_section=cross_section,
@@ -124,9 +132,9 @@ def add_fiber_array(
 
     component_new.add_ref(component)
 
-    for pname, p in component.ports.items():
-        if p.name not in optical_ports_names:
-            component_new.add_port(pname, port=p)
+    for port in component.ports.values():
+        if port.name not in optical_ports_names:
+            component_new.add_port(port.name, port=port)
 
     ports = sort_ports_x(ports)
 
@@ -143,6 +151,7 @@ def add_fiber_array(
                 port = ports[0]
                 component_new.add_port(f"{port.name}_{i}{j}", port=port)
 
+    component_new.copy_child_info(component)
     return component_new
 
 
@@ -167,8 +176,8 @@ if __name__ == "__main__":
     gctm = gf.components.grating_coupler_tm
 
     # from pprint import pprint
-    layer_label = gf.LAYER.TEXT
-    layer_label = (66, 5)
+    # layer_label = gf.LAYER.TEXT
+    # layer_label = (66, 5)
 
     # cc = demo_tapers()
     # cc = test_type1()
@@ -177,9 +186,8 @@ if __name__ == "__main__":
     # c = gf.components.straight()
     # c = gf.components.mmi2x2()
     # c = gf.components.ring_single()
-    c = gf.components.straight_heater_metal()
-
-    c.y = 0
+    # c = gf.components.straight_heater_metal()
+    c = gf.components.spiral(direction="NORTH")
     cc = add_fiber_array(
         component=c,
         # optical_routing_type=0,
