@@ -9,6 +9,7 @@ get_bundle calls different function depending on the port orientation.
  - get_bundle_uindirect: ports with indirect U-turns
 
 """
+from functools import partial
 from typing import Callable, List, Optional, Union, cast
 
 import numpy as np
@@ -17,7 +18,8 @@ from numpy import ndarray
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.bend_euler import bend_euler
-from gdsfactory.components.straight import straight
+from gdsfactory.components.straight import straight as straight_function
+from gdsfactory.components.wire import wire_corner
 from gdsfactory.config import TECH
 from gdsfactory.cross_section import strip
 from gdsfactory.port import Port
@@ -37,11 +39,11 @@ def get_bundle(
     ports2: List[Port],
     separation: float = 5.0,
     extension_length: float = 0.0,
-    straight_factory: ComponentFactory = straight,
-    bend_factory: ComponentFactory = bend_euler,
+    straight: ComponentFactory = straight_function,
+    bend: ComponentFactory = bend_euler,
     sort_ports: bool = True,
-    end_straight_offset: float = 0.0,
-    start_straight: Optional[float] = None,
+    end_straight_length: float = 0.0,
+    start_straight_length: Optional[float] = None,
     cross_section: CrossSectionFactory = strip,
     **kwargs,
 ) -> List[Route]:
@@ -51,12 +53,12 @@ def get_bundle(
     Args:
         ports1: should all be facing in the same direction
         ports2: should all be facing in the same direction
-        separation: straight separation
+        separation: bundle separation (center to center)
         extension_length: adds straight extension
-        bend_factory:
+        bend:
         sort_ports:
-        end_straight_offset:
-        start_straight:
+        end_straight_length:
+        start_straight_length:
         cross_section:
         **kwargs: cross_section settings
 
@@ -88,7 +90,7 @@ def get_bundle(
     ports2 = cast(List[Port], ports2)
 
     x = cross_section(**kwargs)
-    start_straight = start_straight or x.info.get("min_length")
+    start_straight_length = start_straight_length or x.info.get("min_length")
 
     if sort_ports:
         ports1, ports2 = sort_ports_function(ports1, ports2)
@@ -103,10 +105,10 @@ def get_bundle(
         "ports1": ports1,
         "ports2": ports2,
         "separation": separation,
-        "start_straight": start_straight,
-        "end_straight_offset": end_straight_offset,
-        "bend_factory": bend_factory,
-        "straight_factory": straight_factory,
+        "start_straight_length": start_straight_length,
+        "end_straight_length": end_straight_length,
+        "bend": bend,
+        "straight": straight,
         "cross_section": cross_section,
     }
     params.update(**kwargs)
@@ -179,9 +181,9 @@ def get_bundle_same_axis(
     ports1: List[Port],
     ports2: List[Port],
     separation: float = 5.0,
-    end_straight_offset: float = 0.0,
-    start_straight: float = 0.0,
-    bend_factory: ComponentFactory = bend_euler,
+    end_straight_length: float = 0.0,
+    start_straight_length: float = 0.0,
+    bend: ComponentFactory = bend_euler,
     sort_ports: bool = True,
     cross_section: CrossSectionFactory = strip,
     **kwargs,
@@ -193,14 +195,14 @@ def get_bundle_same_axis(
         ports2: second list of ports
         separation: minimum separation between two straights
         axis: specifies "X" or "Y"
-              X (resp. Y) -> indicates that the ports should be sorted and
-             compared using the X (resp. Y) axis
+            X (resp. Y) -> indicates that the ports should be sorted and
+            compared using the X (resp. Y) axis
         route_filter: filter to apply to the manhattan waypoints
             e.g `get_route_from_waypoints` for deep etch strip straight
-        end_straight_offset: offset to add at the end of each straight
+        end_straight_length: offset to add at the end of each straight
         sort_ports: sort the ports according to the axis.
         cross_section: cross_section
-        **kwargs: cross_section settings
+        kwargs: cross_section settings
 
     Returns:
         `[route_filter(r) for r in routes]` list of lists of coordinates
@@ -221,8 +223,8 @@ def get_bundle_same_axis(
         2 X          X          X          X          X          X
 
 
-    start: at the top
-    end: at the bottom
+    ports1: at the top
+    ports2: at the bottom
 
     The general strategy is:
     Group tracks which would collide together and apply the following method
@@ -249,16 +251,16 @@ def get_bundle_same_axis(
         ports1,
         ports2,
         separation=separation,
-        bend_factory=bend_factory,
+        bend=bend,
         cross_section=cross_section,
-        end_straight_offset=end_straight_offset,
-        start_straight=start_straight,
+        end_straight_length=end_straight_length,
+        start_straight_length=start_straight_length,
         **kwargs,
     )
     return [
         get_route_from_waypoints(
             route,
-            bend_factory=bend_factory,
+            bend=bend,
             cross_section=cross_section,
             **kwargs,
         )
@@ -270,9 +272,9 @@ def _get_bundle_waypoints(
     ports1: List[Port],
     ports2: List[Port],
     separation: float = 30,
-    end_straight_offset: float = 0.0,
+    end_straight_length: float = 0.0,
     tol: float = 0.00001,
-    start_straight: float = 0.0,
+    start_straight_length: float = 0.0,
     cross_section: CrossSectionFactory = strip,
     **kwargs,
 ) -> List[ndarray]:
@@ -282,9 +284,9 @@ def _get_bundle_waypoints(
         ports1: list of starting ports
         ports2: list of end ports
         separation: route spacing
-        end_straight_offset: adds a straigth
+        end_straight_length: adds a straigth
         tol: tolerance
-        start_straight: length of straight
+        start_straight_length: length of straight
         cross_section: cross_section
         kwargs: cross_section settings
     """
@@ -310,8 +312,8 @@ def _get_bundle_waypoints(
             generate_manhattan_waypoints(
                 ports1[0],
                 ports2[0],
-                start_straight=start_straight,
-                end_straight=end_straight_offset,
+                start_straight_length=start_straight_length,
+                end_straight_length=end_straight_length,
                 cross_section=cross_section,
                 **kwargs,
             )
@@ -342,13 +344,11 @@ def _get_bundle_waypoints(
     s = sign(y0 - y1)
     curr_end_straight = 0
 
-    end_straight_offset = end_straight_offset or 15.0
+    end_straight_length = end_straight_length or 15.0
 
-    Le = end_straight_offset
+    Le = end_straight_length
 
     # First pass - loop on all the ports to find the tentative end_straights
-    _w = get_port_width
-
     for i in range(len(ports1)):
         if axis in ["X", "x"]:
             x1 = get_port_y(ports1[i])
@@ -361,22 +361,7 @@ def _get_bundle_waypoints(
 
         dx = abs(x2 - x1)
 
-        # Compute the metal separation to use. This depends on the adjacent metal
-        # track widths
-        if i != len(ports1) - 1 and i != 0:
-            # Deal with any track which is not on the edge
-            max_width = max(_w(ports1[i + 1]), _w(ports1[i - 1]))
-            curr_sep = 0.5 * (_w(ports1[i]) + max_width) + separation
-
-        elif i == 0:
-            # Deal with start edge case
-            curr_sep = separation + 0.5 * (_w(ports1[0]) + _w(ports1[1]))
-
-        elif i == len(ports1) - 1:
-            # Deal with end edge case
-            curr_sep = separation + 0.5 * (_w(ports1[-2]) + _w(ports1[-1]))
-
-        if are_decoupled(x2, x2_prev, x1, x1_prev, sep=curr_sep):
+        if are_decoupled(x2, x2_prev, x1, x1_prev, sep=separation):
             # If this metal track does not impact the previous one, then start a new
             # group.
             L = min(end_straights_in_group)
@@ -389,9 +374,9 @@ def _get_bundle_waypoints(
 
         else:
             if x2 >= x1:
-                curr_end_straight += curr_sep
+                curr_end_straight += separation
             else:
-                curr_end_straight -= curr_sep
+                curr_end_straight -= separation
 
         end_straights_in_group.append(curr_end_straight + (y - y0) * s)
         number_o_connectors_in_group += 1
@@ -422,8 +407,8 @@ def _get_bundle_waypoints(
                 generate_manhattan_waypoints(
                     ports1[i],
                     ports2[i],
-                    start_straight=start_straight,
-                    end_straight=end_straights[i],
+                    start_straight_length=start_straight_length,
+                    end_straight_length=end_straights[i],
                     cross_section=cross_section,
                     **kwargs,
                 )
@@ -434,8 +419,8 @@ def _get_bundle_waypoints(
                 generate_manhattan_waypoints(
                     ports1[i],
                     ports2[i],
-                    start_straight=start_straight,
-                    end_straight=end_straights[i],
+                    start_straight_length=start_straight_length,
+                    end_straight_length=end_straights[i],
                     cross_section=cross_section,
                     **kwargs,
                 )
@@ -488,13 +473,13 @@ def get_min_spacing(
             ports1.sort(key=get_port_x)
             ports2.sort(key=get_port_x)
 
-    for i, _ in enumerate(ports1):
+    for port1, port2 in zip(ports1, ports2):
         if axis in ["X", "x"]:
-            x1 = get_port_y(ports1[i])
-            x2 = get_port_y(ports2[i])
+            x1 = get_port_y(ports1)
+            x2 = get_port_y(port2)
         else:
-            x1 = get_port_x(ports1[i])
-            x2 = get_port_x(ports2[i])
+            x1 = get_port_x(port1)
+            x2 = get_port_x(port2)
         if x2 >= x1:
             j += 1
         else:
@@ -513,8 +498,8 @@ def get_bundle_same_axis_no_grouping(
     ports2: List[Port],
     sep: float = 5.0,
     route_filter: Callable = get_route,
-    start_straight: Optional[float] = None,
-    end_straight: Optional[float] = None,
+    start_straight_length: Optional[float] = None,
+    end_straight_length: Optional[float] = None,
     sort_ports: bool = True,
     cross_section: CrossSectionFactory = strip,
     **kwargs,
@@ -558,8 +543,8 @@ def get_bundle_same_axis_no_grouping(
         route_filter: ManhattanExpandedWgConnector or ManhattanWgConnector
             or any other connector function with the same input
         radius: bend radius. If unspecified, uses the default radius
-        start_straight: offset on the starting length before the first bend
-        end_straight: offset on the ending length after the last bend
+        start_straight_length: offset on the starting length before the first bend
+        end_straight_length: offset on the ending length after the last bend
         sort_ports: True -> sort the ports according to the axis. False -> no sort applied
 
     Returns:
@@ -606,14 +591,14 @@ def get_bundle_same_axis_no_grouping(
             max_j = j
     j = 0
 
-    if start_straight is None:
-        start_straight = 0.2
+    if start_straight_length is None:
+        start_straight_length = 0.2
 
-    if end_straight is None:
-        end_straight = 0.2
+    if end_straight_length is None:
+        end_straight_length = 0.2
 
-    start_straight += max_j * sep
-    end_straight += -min_j * sep
+    start_straight_length += max_j * sep
+    end_straight_length += -min_j * sep
 
     # Do case with wire direct if the ys are close to each other
     for i, _ in enumerate(ports1):
@@ -625,15 +610,15 @@ def get_bundle_same_axis_no_grouping(
             x1 = ports1[i].position[0]
             x2 = ports2[i].position[0]
 
-        s_straight = start_straight - j * sep
-        e_straight = j * sep + end_straight
+        s_straight = start_straight_length - j * sep
+        e_straight = j * sep + end_straight_length
 
         elems += [
             route_filter(
                 ports1[i],
                 ports2[i],
-                start_straight=s_straight,
-                end_straight=e_straight,
+                start_straight_length=s_straight,
+                end_straight_length=e_straight,
                 cross_section=cross_section,
                 **kwargs,
             )
@@ -646,10 +631,13 @@ def get_bundle_same_axis_no_grouping(
     return elems
 
 
+get_bundle_electrical = partial(
+    get_bundle, bend=wire_corner, cross_section=gf.cross_section.metal3
+)
+
+
 @gf.cell
 def test_get_bundle_small() -> Component:
-    import gdsfactory as gf
-
     c = gf.Component()
     c1 = c << gf.components.mmi2x2()
     c2 = c << gf.components.mmi2x2()
@@ -658,9 +646,10 @@ def test_get_bundle_small() -> Component:
         [c1.ports["o3"], c1.ports["o4"]],
         [c2.ports["o1"], c2.ports["o2"]],
         radius=5,
+        separation=5.0,
     )
     for route in routes:
-        assert np.isclose(route.length, 111.3), route.length
+        assert np.isclose(route.length, 111.136), route.length
         c.add(route.references)
     return c
 
