@@ -1,6 +1,8 @@
+import uuid
 import warnings
 from typing import Callable, Dict, List, Optional, Tuple
 
+import gdspy
 import numpy as np
 import pytest
 from numpy import bool_, ndarray
@@ -8,16 +10,20 @@ from numpy import bool_, ndarray
 import gdsfactory as gf
 from gdsfactory.component import Component, ComponentReference
 from gdsfactory.components.bend_euler import bend_euler
-from gdsfactory.components.straight import straight
+from gdsfactory.components.bend_s import bend_s
+from gdsfactory.components.straight import straight as straight_function
+from gdsfactory.components.taper import taper as taper_function
 from gdsfactory.cross_section import strip
-from gdsfactory.geo_utils import angles_deg
+from gdsfactory.geometry.functions import angles_deg
 from gdsfactory.port import Port, select_ports_list
 from gdsfactory.snap import snap_to_grid
+from gdsfactory.tech import LAYER
 from gdsfactory.types import (
     ComponentFactory,
     ComponentOrFactory,
     Coordinate,
     Coordinates,
+    CrossSection,
     CrossSectionFactory,
     Layer,
     Route,
@@ -34,6 +40,10 @@ class RouteWarning(UserWarning):
     pass
 
 
+class RouteError(ValueError):
+    pass
+
+
 def sign(x: float) -> int:
     return -1 if x < 0 else 1
 
@@ -126,9 +136,7 @@ def gen_sref(
         ref.reflect(p1=(0, y0), p2=(1, y0))
 
     ref.rotate(rotation_angle, center=port_position)
-
     ref.move(port_position, position)
-
     return ref
 
 
@@ -146,7 +154,7 @@ def get_straight_distance(p0: ndarray, p1: ndarray) -> float:
     if _is_horizontal(p0, p1):
         return np.abs(p0[0] - p1[0])
 
-    raise ValueError(f"Waveguide points {p0} {p1} are not manhattan")
+    raise RouteError(f"Waveguide points {p0} {p1} are not manhattan")
 
 
 def transform(
@@ -221,9 +229,9 @@ def _generate_route_manhattan_points(
     output_port: Port,
     bs1: float,
     bs2: float,
-    start_straight: float = 0.01,
-    end_straight: float = 0.01,
-    min_straight: float = 0.01,
+    start_straight_length: float = 0.01,
+    end_straight_length: float = 0.01,
+    min_straight_length: float = 0.01,
 ) -> ndarray:
     """Return list of ports for the route.
 
@@ -232,9 +240,9 @@ def _generate_route_manhattan_points(
         output_port:
         bs1: bend size
         bs2: bend size
-        start_straight:
-        end_straight:
-        min_straight:
+        start_straight_length:
+        end_straight_length:
+        min_straight_length:
     """
 
     threshold = TOLERANCE
@@ -242,20 +250,18 @@ def _generate_route_manhattan_points(
     # transform I/O to the case where output is at (0, 0) pointing east (180)
     p_input = input_port.midpoint
     p_output = output_port.midpoint
-
     pts_io = np.stack([p_input, p_output], axis=0)
-
     angle = output_port.orientation
 
-    a0 = -angle + 180
-    transform_params = (-p_output, a0, False)
+    bend_orientation = -angle + 180
+    transform_params = (-p_output, bend_orientation, False)
 
     _pts_io = transform(pts_io, *transform_params)
     p = _pts_io[0, :]
     _p_output = _pts_io[1, :]
 
-    a = int(input_port.orientation + a0) % 360
-    s = start_straight
+    a = int(input_port.orientation + bend_orientation) % 360
+    s = start_straight_length
     count = 0
     points = [p]
 
@@ -278,19 +284,21 @@ def _generate_route_manhattan_points(
                 points += [_p_output]
                 break
             elif (
-                p[0] + (bs1 + bs2 + end_straight + s) < threshold
-                and abs(p[1]) - (bs1 + bs2 + min_straight) > -threshold
+                p[0] + (bs1 + bs2 + end_straight_length + s) < threshold
+                and abs(p[1]) - (bs1 + bs2 + min_straight_length) > -threshold
             ):
                 # sufficient space for S-bend
-                p = (-end_straight - bs2, p[1])
+                p = (-end_straight_length - bs2, p[1])
                 a = -sigp * 90
             elif (
-                p[0] + (2 * bs1 + 2 * bs2 + end_straight + s + min_straight) < threshold
+                p[0]
+                + (2 * bs1 + 2 * bs2 + end_straight_length + s + min_straight_length)
+                < threshold
             ):
                 # sufficient distance to move aside
                 p = (p[0] + s + bs1, p[1])
                 a = -sigp * 90
-            elif abs(p[1]) - (2 * bs1 + 2 * bs2 + 2 * min_straight) > -threshold:
+            elif abs(p[1]) - (2 * bs1 + 2 * bs2 + 2 * min_straight_length) > -threshold:
                 p = (p[0] + s + bs1, p[1])
                 a = -sigp * 90
             else:
@@ -299,14 +307,17 @@ def _generate_route_manhattan_points(
 
         elif a == 180:
             # opposite directions
-            if abs(p[1]) - (bs1 + bs2 + min_straight) > -threshold:
+            if abs(p[1]) - (bs1 + bs2 + min_straight_length) > -threshold:
                 # far enough: U-turn
-                p = (min(p[0] - s, -end_straight) - bs2, p[1])
+                p = (min(p[0] - s, -end_straight_length) - bs2, p[1])
                 a = -sigp * 90
             else:
                 # more complex turn
                 p = (
-                    min(p[0] - s - bs1, -end_straight - min_straight - 2 * bs1 - bs2),
+                    min(
+                        p[0] - s - bs1,
+                        -end_straight_length - min_straight_length - 2 * bs1 - bs2,
+                    ),
                     p[1],
                 )
                 a = -sigp * 90
@@ -316,40 +327,46 @@ def _generate_route_manhattan_points(
                 siga = 1
 
             if ((-p[1] * siga) - (s + bs2) > -threshold) and (
-                -p[0] - (end_straight + bs2)
+                -p[0] - (end_straight_length + bs2)
             ) > -threshold:
                 # simple case: one right angle to the end
                 p = (p[0], 0)
                 a = 0
             elif (p[1] * siga) <= threshold and p[0] + (
-                end_straight + bs1
+                end_straight_length + bs1
             ) > -threshold:
                 # go to the west, and then turn upward
                 # this will sometimes result in too sharp bends, but there is no
                 # avoiding this!
 
                 _y = min(
-                    max(min(min_straight, 0.5 * abs(p[1])), abs(p[1]) - s - bs1),
-                    bs1 + bs2 + min_straight,
+                    max(min(min_straight_length, 0.5 * abs(p[1])), abs(p[1]) - s - bs1),
+                    bs1 + bs2 + min_straight_length,
                 )
 
                 p = (p[0], sigp * _y)
                 if count == 1:  # take care of the start_straight case
-                    p = (p[0], -sigp * max(start_straight, _y))
+                    p = (p[0], -sigp * max(start_straight_length, _y))
 
                 a = 180
-            elif -p[0] - (end_straight + 2 * bs1 + bs2 + min_straight) > -threshold:
+            elif (
+                -p[0] - (end_straight_length + 2 * bs1 + bs2 + min_straight_length)
+                > -threshold
+            ):
                 # go sufficiently up, and then east
-                p = (p[0], siga * max(p[1] * siga + s + bs1, bs1 + bs2 + min_straight))
+                p = (
+                    p[0],
+                    siga * max(p[1] * siga + s + bs1, bs1 + bs2 + min_straight_length),
+                )
                 a = 0
 
-            elif -p[0] - (end_straight + bs2) > -threshold:
+            elif -p[0] - (end_straight_length + bs2) > -threshold:
                 # make vertical S-bend to get sufficient room for movement
                 points += [(p[0], p[1] + siga * (bs2 + s))]
                 p = (
                     min(
-                        p[0] - bs1 + bs2 + min_straight,
-                        -2 * bs1 - bs2 - end_straight - min_straight,
+                        p[0] - bs1 + bs2 + min_straight_length,
+                        -2 * bs1 - bs2 - end_straight_length - min_straight_length,
                     ),
                     p[1] + siga * (bs2 + s),
                 )
@@ -359,7 +376,7 @@ def _generate_route_manhattan_points(
                 p = (p[0], p[1] + sigp * (s + bs1))
                 a = 180
         points += [p]
-        s = min_straight + bs1
+        s = min_straight_length + bs1
 
     points = np.stack([np.array(_p) for _p in points], axis=0)
     points = reverse_transform(points, *transform_params)
@@ -419,8 +436,6 @@ def _get_bend_reference_parameters(
     bsx = b2[0] - b1[0]
     bsy = b2[1] - b1[1]
 
-    # raise_error_if_not_routable([p0, p1, p2], radius=bend_cell.radius)
-
     dp1 = p1 - p0
     dp2 = p2 - p1
     is_h_dp1 = np.abs(dp1[1]) < TOLERANCE
@@ -474,15 +489,62 @@ def remove_flat_angles(points: ndarray) -> ndarray:
     return points
 
 
+def get_route_error(
+    points,
+    cross_section: Optional[CrossSection] = None,
+    layer_path: Layer = LAYER.ERROR_PATH,
+    layer_label: Layer = LAYER.TEXT,
+    layer_marker: Layer = LAYER.ERROR_MARKER,
+    references: Optional[List[ComponentReference]] = None,
+) -> Route:
+    width = cross_section.info["width"] if cross_section else 10
+    warnings.warn(
+        f"Route error for points {points}",
+        RouteWarning,
+    )
+
+    c = Component(f"route_{uuid.uuid4()}"[:16])
+    path = gdspy.FlexPath(
+        points,
+        width=width,
+        gdsii_path=True,
+        layer=layer_path[0],
+        datatype=layer_path[1],
+    )
+    c.add(path)
+    ref = ComponentReference(c)
+    port1 = gf.Port(name="p1", midpoint=points[0], width=width)
+    port2 = gf.Port(name="p2", midpoint=points[1], width=width)
+
+    point_marker = gf.c.rectangle(
+        size=(width * 2, width * 2), centered=True, layer=layer_marker
+    )
+    point_markers = [point_marker.ref(position=point) for point in points] + [ref]
+    labels = [
+        gf.Label(
+            text=str(i), position=point, layer=layer_label[0], texttype=layer_label[1]
+        )
+        for i, point in enumerate(points)
+    ]
+
+    references = references or []
+    references += point_markers
+    return Route(references=references, ports=[port1, port2], length=-1, labels=labels)
+
+
 def round_corners(
     points: Coordinates,
-    straight_factory: ComponentFactory = straight,
-    bend_factory: ComponentFactory = bend_euler,
+    straight: ComponentFactory = straight_function,
+    bend: ComponentFactory = bend_euler,
+    bend_s_factory: Optional[ComponentFactory] = bend_s,
     taper: Optional[ComponentFactory] = None,
-    straight_factory_fall_back_no_taper: Optional[ComponentFactory] = None,
+    straight_fall_back_no_taper: Optional[ComponentFactory] = None,
     mirror_straight: bool = False,
     straight_ports: Optional[List[str]] = None,
     cross_section: CrossSectionFactory = strip,
+    on_route_error: Callable = get_route_error,
+    with_point_markers: bool = False,
+    snap_to_grid_nm: Optional[int] = 1,
     **kwargs,
 ) -> Route:
     """Returns Route:
@@ -494,26 +556,36 @@ def round_corners(
     Args:
         points: manhattan route defined by waypoints
         bend90: the bend to use for 90Deg turns
-        straight_factory: the straight library to use to generate straight portions
+        straight: the straight library to use to generate straight portions
         taper: taper for straight portions. If None, no tapering
-        straight_factory_fall_back_no_taper: in case there is no space for two tapers
+        straight_fall_back_no_taper: in case there is no space for two tapers
         mirror_straight: mirror_straight waveguide
         straight_ports: port names for straights. If None finds them automatically.
         cross_section:
-        **kwargs: cross_section settings
+        on_route_error: function to run when route fails
+        with_point_markers: add route points markers (easy for debugging)
+        snap_to_grid_nm: nm to snap to grid
+        kwargs: cross_section settings
     """
     x = cross_section(**kwargs)
+    points = (
+        gf.snap.snap_to_grid(points, nm=snap_to_grid_nm) if snap_to_grid_nm else points
+    )
 
     auto_widen = x.info.get("auto_widen", False)
     auto_widen_minimum_length = x.info.get("auto_widen_minimum_length", 200.0)
     taper_length = x.info.get("taper_length", 10.0)
+    width = x.info.get("width", 2.0)
+    width_wide = x.info.get("width_wide", None)
     references = []
-    bend90 = (
-        bend_factory(cross_section=cross_section, **kwargs)
-        if callable(bend_factory)
-        else bend_factory
+    bend90 = bend(cross_section=cross_section, **kwargs) if callable(bend) else bend
+    # bsx = bsy = _get_bend_size(bend90)
+    taper = taper or taper_function(
+        cross_section=cross_section,
+        width1=width,
+        width2=width_wide,
+        length=taper_length,
     )
-    # radius = bend90.radius
     taper = taper(cross_section=cross_section, **kwargs) if callable(taper) else taper
 
     # If there is a taper, make sure its length is known
@@ -522,54 +594,53 @@ def round_corners(
             _taper_ports = list(taper.ports.values())
             taper.info["length"] = _taper_ports[-1].x - _taper_ports[0].x
 
-    straight_factory_fall_back_no_taper = (
-        straight_factory_fall_back_no_taper or straight_factory
-    )
+    straight_fall_back_no_taper = straight_fall_back_no_taper or straight
 
     # Remove any flat angle, otherwise the algorithm won't work
     points = remove_flat_angles(points)
     points = np.array(points)
 
-    # raise_error_if_not_routable(points, radius=radius)
-
     straight_sections = []  # (p0, angle, length)
     p0_straight = points[0]
     p1 = points[1]
 
     total_length = 0  # Keep track of the total path length
-    # bend_length = getattr(bend90, "length", 0)
 
-    if not hasattr(bend90, "length"):
-        raise ValueError(f"bend {bend90} needs to have bend.length defined")
+    if not hasattr(bend90.info, "length"):
+        raise ValueError(f"bend {bend90} needs to have bend.info.length defined")
 
-    bend_length = bend90.length
+    bend_length = bend90.info.length
 
     dp = p1 - p0_straight
-    a0 = None
+    bend_orientation = None
     if _is_vertical(p0_straight, p1):
         if dp[1] > 0:
-            a0 = 90
+            bend_orientation = 90
         elif dp[1] < 0:
-            a0 = 270
+            bend_orientation = 270
     elif _is_horizontal(p0_straight, p1):
         if dp[0] > 0:
-            a0 = 0
+            bend_orientation = 0
         elif dp[0] < 0:
-            a0 = 180
+            bend_orientation = 180
 
-    assert a0 is not None, f"Points should be manhattan, got {p0_straight} {p1}"
+    if bend_orientation is None:
+        return on_route_error(points=points, cross_section=x)
+
+    layer = x.info["layer"]
     try:
         pname_west, pname_north = [
-            p.name for p in _get_bend_ports(bend=bend90, layer=x.info["layer"])
+            p.name for p in _get_bend_ports(bend=bend90, layer=layer)
         ]
-    except ValueError:
+    except ValueError as exc:
         raise ValueError(
-            f'Did not find 2 ports on layer {x.info["layer"]}. Got {list(bend90.ports.values())}'
-        )
+            f"Did not find 2 ports on layer {layer}. Got {list(bend90.ports.values())}"
+        ) from exc
     n_o_bends = points.shape[0] - 2
     total_length += n_o_bends * bend_length
 
     previous_port_point = points[0]
+    bend_points = [previous_port_point]
 
     # Add bend sections and record straight-section information
     for i in range(1, points.shape[0] - 1):
@@ -584,56 +655,89 @@ def round_corners(
 
         if abs(dx_points) < TOLERANCE:
             matching_ports = [
-                port for port in bend_ref.ports.values() if port.x == points[i][0]
+                port
+                for port in bend_ref.ports.values()
+                if np.isclose(port.x, points[i][0])
             ]
 
         if abs(dy_points) < TOLERANCE:
             matching_ports = [
-                port for port in bend_ref.ports.values() if port.y == points[i][1]
+                port
+                for port in bend_ref.ports.values()
+                if np.isclose(port.y, points[i][1])
             ]
 
         if matching_ports:
             next_port = matching_ports[0]
             other_port_name = set(bend_ref.ports.keys()) - {next_port.name}
             other_port = bend_ref.ports[list(other_port_name)[0]]
-
-            dx_bend = next_port.x - previous_port_point[0]
-            dy_bend = next_port.y - previous_port_point[1]
-
+            bend_points.append(next_port.midpoint)
+            bend_points.append(other_port.midpoint)
             previous_port_point = other_port.midpoint
 
-            if dx_points * dx_bend < 0 or dy_points * dy_bend < 0:
-                # print(dx_points, dx_bend, dy_points, dy_bend)
-                radius = bend_ref.get_property("dy")
-                warnings.warn(
-                    f"90deg bend with radius = {radius} does not fit into the route",
-                    RouteWarning,
+        try:
+            straight_sections += [
+                (
+                    p0_straight,
+                    bend_orientation,
+                    get_straight_distance(p0_straight, bend_origin),
                 )
-
-        straight_sections += [
-            (p0_straight, a0, get_straight_distance(p0_straight, bend_origin))
-        ]
+            ]
+        except RouteError:
+            on_route_error(
+                points=(p0_straight, bend_origin),
+                cross_section=x,
+                references=references,
+            )
 
         p0_straight = bend_ref.ports[pname_north].midpoint
-        a0 = bend_ref.ports[pname_north].orientation
+        bend_orientation = bend_ref.ports[pname_north].orientation
 
-    straight_sections += [
-        (p0_straight, a0, get_straight_distance(p0_straight, points[-1]))
-    ]
+    bend_points.append(points[-1])
+
+    try:
+        straight_sections += [
+            (
+                p0_straight,
+                bend_orientation,
+                get_straight_distance(p0_straight, points[-1]),
+            )
+        ]
+    except RouteError:
+        on_route_error(
+            points=(p0_straight, points[-1]),
+            cross_section=x,
+            references=references,
+        )
+
+    # with_point_markers=True
+    # print()
+    # for i, point in enumerate(points):
+    #     print(i, point)
+    # print()
+    # for i, point in enumerate(bend_points):
+    #     print(i, point)
+
+    # ensure bend connectivity
+    for i, point in enumerate(points[:-1]):
+        sx = np.sign(points[i + 1][0] - point[0])
+        sy = np.sign(points[i + 1][1] - point[1])
+        bsx = np.sign(bend_points[2 * i + 1][0] - bend_points[2 * i][0])
+        bsy = np.sign(bend_points[2 * i + 1][1] - bend_points[2 * i][1])
+        if bsx * sx == -1 or bsy * sy == -1:
+            return on_route_error(points=points, cross_section=x, references=references)
 
     wg_refs = []
     for straight_origin, angle, length in straight_sections:
         with_taper = False
         # wg_width = list(bend90.ports.values())[0].width
-
+        length = snap_to_grid(length)
         total_length += length
 
-        if auto_widen and taper is not None and length > auto_widen_minimum_length:
-            length = length - 2 * taper_length
-            with_taper = True
-
-        if with_taper:
+        if auto_widen and length > auto_widen_minimum_length and width_wide:
             # Taper starts where straight would have started
+            with_taper = True
+            length = length - 2 * taper_length
             taper_origin = straight_origin
 
             pname_west, pname_east = [
@@ -643,24 +747,19 @@ def round_corners(
                 position=taper_origin, port_id=pname_west, rotation=angle
             )
 
-            taper_width = taper.ports[pname_east].width
-
             references.append(taper_ref)
             wg_refs += [taper_ref]
 
             # Update start straight position
             straight_origin = taper_ref.ports[pname_east].midpoint
 
-        # Straight waveguide
-        length = snap_to_grid(length)
-        if with_taper:
+            # Straight waveguide
             kwargs_wide = kwargs.copy()
-            kwargs_wide.update(width=taper_width)
-            wg = straight_factory(
-                length=length, cross_section=cross_section, **kwargs_wide
-            )
+            kwargs_wide.update(width=width_wide)
+            cross_section_wide = gf.partial(cross_section, **kwargs_wide)
+            wg = straight(length=length, cross_section=cross_section_wide)
         else:
-            wg = straight_factory_fall_back_no_taper(
+            wg = straight_fall_back_no_taper(
                 length=length, cross_section=cross_section, **kwargs
             )
 
@@ -670,8 +769,8 @@ def round_corners(
             ]
         pname_west, pname_east = straight_ports
 
-        wg.move(wg.ports[pname_west], (0, 0))
         wg_ref = wg.ref()
+        wg_ref.move(wg.ports[pname_west], (0, 0))
         if mirror_straight:
             wg_ref.reflect_v(list(wg_ref.ports.values())[0].name)
 
@@ -691,14 +790,29 @@ def round_corners(
             pname_west, pname_east = [
                 p.name for p in _get_straight_ports(taper, layer=x.info["layer"])
             ]
-            taper_ref = taper.ref(
-                position=taper_origin, port_id=pname_east, rotation=angle + 180
-            )
 
+            taper_ref = taper.ref(
+                position=taper_origin,
+                port_id=pname_east,
+                rotation=angle + 180,
+                v_mirror=True,
+            )
+            # references += [
+            #     gf.Label(
+            #         text=f"a{angle}",
+            #         position=taper_ref.center,
+            #         layer=2,
+            #         texttype=0,
+            #     )
+            # ]
             references.append(taper_ref)
             wg_refs += [taper_ref]
             port_index_out = 0
 
+    if with_point_markers:
+        route = get_route_error(points, cross_section=x)
+        references += route.references
+
     port_input = list(wg_refs[0].ports.values())[0]
     port_output = list(wg_refs[-1].ports.values())[port_index_out]
     length = snap_to_grid(float(total_length))
@@ -708,34 +822,31 @@ def round_corners(
 def generate_manhattan_waypoints(
     input_port: Port,
     output_port: Port,
-    straight_factory: ComponentFactory = straight,
-    start_straight: Optional[float] = None,
-    end_straight: Optional[float] = None,
-    min_straight: Optional[float] = None,
-    bend_factory: ComponentFactory = bend_euler,
+    straight: ComponentFactory = straight_function,
+    start_straight_length: Optional[float] = None,
+    end_straight_length: Optional[float] = None,
+    min_straight_length: Optional[float] = None,
+    bend: ComponentFactory = bend_euler,
     cross_section: CrossSectionFactory = strip,
     **kwargs,
 ) -> ndarray:
     """Return waypoints for a Manhattan route between two ports."""
 
-    bend90 = (
-        bend_factory(cross_section=cross_section, **kwargs)
-        if callable(bend_factory)
-        else bend_factory
-    )
+    bend90 = bend(cross_section=cross_section, **kwargs) if callable(bend) else bend
     x = cross_section(**kwargs)
-    start_straight = start_straight or x.info.get("min_length")
-    end_straight = end_straight or x.info.get("min_length")
-    min_straight = min_straight or x.info.get("min_length")
-
-    # pname_west, pname_north = [
-    #     p.name
-    #     for p in _get_bend_ports(bend=bend90, layer=x.info["layer"])
-    # ]
+    start_straight_length = start_straight_length or x.info.get("min_length")
+    end_straight_length = end_straight_length or x.info.get("min_length")
+    min_straight_length = min_straight_length or x.info.get("min_length")
 
     bsx = bsy = _get_bend_size(bend90)
     points = _generate_route_manhattan_points(
-        input_port, output_port, bsx, bsy, start_straight, end_straight, min_straight
+        input_port,
+        output_port,
+        bsx,
+        bsy,
+        start_straight_length,
+        end_straight_length,
+        min_straight_length,
     )
     return points
 
@@ -750,13 +861,14 @@ def _get_bend_size(bend90: Component):
 def route_manhattan(
     input_port: Port,
     output_port: Port,
-    straight_factory: ComponentFactory = straight,
+    straight: ComponentFactory = straight_function,
     taper: Optional[ComponentOrFactory] = None,
-    start_straight: Optional[float] = None,
-    end_straight: Optional[float] = None,
-    min_straight: Optional[float] = None,
-    bend_factory: ComponentFactory = bend_euler,
+    start_straight_length: Optional[float] = None,
+    end_straight_length: Optional[float] = None,
+    min_straight_length: Optional[float] = None,
+    bend: ComponentFactory = bend_euler,
     cross_section: CrossSectionFactory = strip,
+    with_point_markers: bool = False,
     **kwargs,
 ) -> Route:
     """Generates the Manhattan waypoints for a route.
@@ -764,33 +876,33 @@ def route_manhattan(
     """
     x = cross_section(**kwargs)
 
-    start_straight = start_straight or x.info.get("min_length")
-    end_straight = end_straight or x.info.get("min_length")
-    min_straight = min_straight or x.info.get("min_length")
+    start_straight_length = start_straight_length or x.info.get("min_length")
+    end_straight_length = end_straight_length or x.info.get("min_length")
+    min_straight_length = min_straight_length or x.info.get("min_length")
 
     points = generate_manhattan_waypoints(
         input_port,
         output_port,
-        start_straight=start_straight,
-        end_straight=end_straight,
-        min_straight=min_straight,
-        bend_factory=bend_factory,
+        start_straight_length=start_straight_length,
+        end_straight_length=end_straight_length,
+        min_straight_length=min_straight_length,
+        bend=bend,
         cross_section=cross_section,
         **kwargs,
     )
     return round_corners(
         points=points,
-        straight_factory=straight_factory,
+        straight=straight,
         taper=taper,
-        bend_factory=bend_factory,
+        bend=bend,
         cross_section=cross_section,
+        with_point_markers=with_point_markers,
         **kwargs,
     )
 
 
 def test_manhattan() -> Component:
-
-    top_cell = gf.Component()
+    top_cell = Component()
 
     inputs = [
         Port("in1", (10, 5), 0.5, 90),
@@ -802,7 +914,7 @@ def test_manhattan() -> Component:
     ]
 
     outputs = [
-        Port("in1", (90, -60), 0.5, 180),
+        Port("in1", (290, -60), 0.5, 180),
         # Port("in2", (-100, 20), 0.5, 0),
         # Port("in3", (100, -25), 0.5, 0),
         # Port("in4", (-150, -65), 0.5, 270),
@@ -810,7 +922,7 @@ def test_manhattan() -> Component:
         # Port("in6", (0, 10), 0.5, 0),
     ]
 
-    lengths = [150.22]
+    lengths = [349.974]
 
     for input_port, output_port, length in zip(inputs, outputs, lengths):
 
@@ -821,10 +933,12 @@ def test_manhattan() -> Component:
         route = route_manhattan(
             input_port=input_port,
             output_port=output_port,
-            straight_factory=straight,
+            straight=straight_function,
             radius=5.0,
-            layer=(2, 0),
-            width=0.2,
+            auto_widen=True,
+            width_wide=2,
+            # layer=(2, 0),
+            # width=0.2,
         )
 
         top_cell.add(route.references)
@@ -857,14 +971,49 @@ def test_manhattan_fail() -> Component:
         [110.0, 80.0],
     ]
     with pytest.warns(RouteWarning):
-        route = round_corners(waypoints, radius=10.0)
+        route = round_corners(waypoints, radius=10.0, with_point_markers=False)
+    c = Component()
+    c.add(route.references)
+    return c
+
+
+def _demo_manhattan_fail() -> Component:
+    waypoints = [
+        [10.0, 0.0],
+        [20.0, 0.0],
+        [20.0, 12.0],
+        [120.0, 12.0],
+        [120.0, 80.0],
+        [110.0, 80.0],
+    ]
+    route = round_corners(waypoints, radius=10.0, with_point_markers=False)
     c = Component()
     c.add(route.references)
     return c
 
 
 if __name__ == "__main__":
-    c = test_manhattan()
+    # c = test_manhattan()
     # c = test_manhattan_fail()
     # c = test_manhattan_pass()
+    # c = _demo_manhattan_fail()
+    # c = gf.c.straight()
+    # c = gf.routing.add_fiber_array(c)
+    # c = gf.c.delay_snake()
+    # c.show()
+
+    c = gf.Component("pads_route_from_steps")
+    pt = c << gf.c.pad_array(orientation=270, columns=3)
+    pb = c << gf.c.pad_array(orientation=90, columns=3)
+    pt.move((100, 200))
+    route = gf.routing.get_route_from_steps(
+        pt.ports["e11"],
+        pb.ports["e11"],
+        steps=[
+            {"y": 100},
+        ],
+        cross_section=gf.cross_section.metal3,
+        bend=gf.components.wire_corner,
+    )
+    c.add(route.references)
     c.show()
