@@ -1,7 +1,5 @@
 from typing import Any, Callable, List, Optional, Tuple, Union
 
-from phidl.device_layout import Label
-
 import gdsfactory as gf
 from gdsfactory.add_labels import get_input_label_text, get_input_label_text_loopback
 from gdsfactory.component import Component, ComponentReference
@@ -18,16 +16,21 @@ from gdsfactory.routing.get_route import get_route_from_waypoints
 from gdsfactory.routing.manhattan import generate_manhattan_waypoints, round_corners
 from gdsfactory.routing.route_south import route_south
 from gdsfactory.routing.utils import direction_ports_from_list_ports
-from gdsfactory.types import ComponentFactory, ComponentOrFactory, CrossSectionFactory
+from gdsfactory.types import (
+    ComponentFactory,
+    ComponentOrFactory,
+    CrossSectionFactory,
+    Label,
+)
 
 
 def route_fiber_array(
     component: Component,
     fiber_spacing: float = TECH.fiber_array_spacing,
     grating_coupler: ComponentOrFactory = grating_coupler_te,
-    bend_factory: ComponentFactory = bend_euler,
-    straight_factory: ComponentFactory = straight,
-    taper_factory: ComponentFactory = taper,
+    bend: ComponentFactory = bend_euler,
+    straight: ComponentFactory = straight,
+    taper: ComponentFactory = taper,
     fanout_length: Optional[float] = None,
     max_y0_optical: None = None,
     with_loopback: bool = True,
@@ -64,8 +67,8 @@ def route_fiber_array(
         component: The component to connect.
         fiber_spacing: the wanted spacing between the optical I/O
         grating_coupler: grating coupler instance, function or list of functions
-        bend_factory:  for bends
-        straight_factory: straight
+        bend:  for bends
+        straight: straight
         fanout_length: target distance between gratings and the southest component port.
             If None, automatically calculated.
         max_y0_optical: Maximum y coordinate at which the intermediate optical ports can be set.
@@ -158,18 +161,14 @@ def route_fiber_array(
     # - grating_couplers is a list of grating couplers
     # Define the route filter to apply to connection methods
 
-    bend90 = (
-        bend_factory(cross_section=cross_section, **kwargs)
-        if callable(bend_factory)
-        else bend_factory
-    )
+    bend90 = bend(cross_section=cross_section, **kwargs) if callable(bend) else bend
 
-    dy = abs(bend90.dy)
+    dy = abs(bend90.info.dy)
 
     # `delta_gr_min` Used to avoid crossing between straights in special cases
     # This could happen when abs(x_port - x_grating) <= 2 * radius
 
-    dy = bend90.dy
+    dy = bend90.info.dy
     delta_gr_min = 2 * dy + 1
 
     offset = (N - 1) * fiber_spacing / 2.0
@@ -240,15 +239,14 @@ def route_fiber_array(
 
     if max_y0_optical is not None:
         y0_optical = round(min(max_y0_optical, y0_optical), 1)
-    """
-     - First connect half of the north ports going from middle of list
-    down to first elements
-     - then connect west ports (top to bottom)
-     - then connect south ports (left to right)
-     - then east ports (bottom to top)
-     - then second half of the north ports (right to left)
 
-    """
+    # - First connect half of the north ports going from middle of list
+    # down to first elements
+    # - then connect west ports (top to bottom)
+    # - then connect south ports (left to right)
+    # - then east ports (bottom to top)
+    # - then second half of the north ports (right to left)
+
     ports = []
     north_ports = direction_ports["N"]
     north_start = north_ports[0 : len(north_ports) // 2]
@@ -264,7 +262,7 @@ def route_fiber_array(
 
     nb_ports_per_line = N // nb_optical_ports_lines
     grating_coupler_si = grating_coupler.size_info
-    y_gr_gap = (K / (nb_optical_ports_lines) + 1) * sep
+    y_gr_gap = (K / nb_optical_ports_lines + 1) * sep
     gr_coupler_y_sep = grating_coupler_si.height + y_gr_gap + dy
 
     offset = (nb_ports_per_line - 1) * fiber_spacing / 2 - x_grating_offset
@@ -310,15 +308,15 @@ def route_fiber_array(
                 waypoints = generate_manhattan_waypoints(
                     input_port=p0,
                     output_port=p1,
-                    bend_factory=bend90,
-                    straight_factory=straight_factory,
+                    bend=bend90,
+                    straight=straight,
                     cross_section=cross_section,
                     **kwargs,
                 )
                 route = route_filter(
                     waypoints=waypoints,
-                    bend_factory=bend90,
-                    straight_factory=straight_factory,
+                    bend=bend90,
+                    straight=straight,
                     cross_section=cross_section,
                     **kwargs,
                 )
@@ -332,9 +330,9 @@ def route_fiber_array(
             straight_separation=straight_separation,
             io_gratings_lines=io_gratings_lines,
             gc_port_name=gc_port_name,
-            bend_factory=bend_factory,
-            straight_factory=straight_factory,
-            taper_factory=taper_factory,
+            bend=bend,
+            straight=straight,
+            taper=taper,
             select_ports=select_ports,
             cross_section=cross_section,
             **kwargs,
@@ -376,9 +374,7 @@ def route_fiber_array(
 
         # If we add align ports, we need enough space for the bends
         end_straight_offset = (
-            straight_separation + 5
-            if with_loopback
-            else x.info.get("min_straight_length")
+            straight_separation + 5 if with_loopback else x.info.get("min_length", 0.1)
         )
         if len(io_gratings_lines) == 1:
             io_gratings = io_gratings_lines[0]
@@ -387,9 +383,9 @@ def route_fiber_array(
                 ports1=to_route,
                 ports2=gc_ports,
                 separation=sep,
-                end_straight_offset=end_straight_offset,
-                straight_factory=straight_factory,
-                bend_factory=bend90,
+                end_straight_length=end_straight_offset,
+                straight=straight,
+                bend=bend90,
                 cross_section=cross_section,
                 **kwargs,
             )
@@ -406,9 +402,9 @@ def route_fiber_array(
                     ports1=to_route[n0 - dn : n0 + dn],
                     ports2=gc_ports,
                     separation=sep,
-                    end_straight_offset=end_straight_offset,
-                    bend_factory=bend90,
-                    straight_factory=straight_factory,
+                    end_straight_length=end_straight_offset,
+                    bend=bend90,
+                    straight=straight,
                     radius=radius,
                     cross_section=cross_section,
                     **kwargs,
@@ -436,7 +432,7 @@ def route_fiber_array(
         p0 = port0.position
         p1 = port1.position
 
-        dy = bend90.dy
+        dy = bend90.info.dy
         dx = max(2 * dy, fiber_spacing / 2)
 
         gc_east = max([gci.size_info.east for gci in grating_couplers])
@@ -456,8 +452,8 @@ def route_fiber_array(
 
         route = round_corners(
             points=points,
-            straight_factory=straight_factory,
-            bend_factory=bend90,
+            straight=straight,
+            bend=bend90,
             cross_section=cross_section,
             **kwargs,
         )
@@ -507,13 +503,13 @@ def demo():
     c = gf.components.straight(length=500)
     c = gf.components.mmi2x2()
 
-    elements, gc, = route_fiber_array(
+    elements, gc, _ = route_fiber_array(
         component=c,
         grating_coupler=[gcte, gctm, gcte, gctm],
         with_loopback=True,
         optical_routing_type=2,
-        # bend_factory=gf.components.bend_euler,
-        bend_factory=gf.components.bend_circular,
+        # bend=gf.components.bend_euler,
+        bend=gf.components.bend_circular,
         radius=20,
         # force_manhattan=True
     )
