@@ -37,19 +37,17 @@ def route_ports_to_side(
     """Routes ports to a given side
 
     Args:
-        ports: the list or dict of ports to be connected to the side
-            can also be a Component or a ComponentReference
-        side should be 'north', 'south', 'east' or 'west'
-        x: only for east/west side routing: the x position where the ports should be sent
-            If None, will use the eastest/westest value
-        y: only for south/north side routing: the y position where the ports should be send
-            If None, will use the southest/northest value
+        ports: list/dict/Component/ComponentReference to route to a side.
+        side: 'north', 'south', 'east' or 'west'.
+        x: position to route ports for east/west. None, uses most east/west value
+        y: position to route ports for south/north. None, uses most north/south value
+
         routing_func: the routing function. By default uses `get_route`
         kwargs:
-            radius
-            separation
-            extend_bottom/extend_top for east/west routing
-            extend_left, extend_right for south/north routing
+          radius
+          separation
+          extend_bottom/extend_top for east/west routing
+          extend_left, extend_right for south/north routing
 
     Returns:
         List of routes:
@@ -115,6 +113,7 @@ def route_ports_to_x(
     y0_top: Optional[float] = None,
     routing_func: Callable = get_route,
     backward_port_side_split_index: int = 0,
+    start_straight_length: float = 0.01,
     **routing_func_args,
 ) -> Tuple[List[Route], List[Port]]:
     """
@@ -144,14 +143,13 @@ def route_ports_to_x(
             all ports with an index larger or equal are routed top
 
     Returns:
-        - a list of connectors which can be added to an element list
-        - a list of the new optical ports
+        routes: list of routes
+        ports: list of the new optical ports
 
-    First route the bottom-half of the back ports
-        (back ports are the one facing opposite side of x)
-    Then route the south ports
-    then the front ports
-    then the north ports
+    1. routes the bottom-half of the ports facing opposite side of x
+    2. routes the south ports
+    3. front ports
+    4. north ports
 
     """
 
@@ -183,7 +181,7 @@ def route_ports_to_x(
     elif isinstance(x, (float, int)):
         pass
     else:
-        raise ValueError(f'x={x} should be a float or "east" or "west"')
+        raise ValueError(f"x={x!r} should be a float or east or west")
 
     if x < min(xs):
         sort_key_north = sort_key_west_to_east
@@ -215,15 +213,17 @@ def route_ports_to_x(
     routes = []
     ports = []
 
-    def add_port(p, y, l_elements, l_ports, start_straight=0.01):
-        new_port = p._copy()
+    def add_port(
+        p, y, l_elements, l_ports, start_straight_length=start_straight_length
+    ):
+        new_port = p.copy()
         new_port.angle = angle
         new_port.position = (x + extension_length, y)
         l_elements += [
             routing_func(
                 p,
                 new_port,
-                start_straight=start_straight,
+                start_straight_length=start_straight_length,
                 radius=radius,
                 **routing_func_args,
             )
@@ -243,50 +243,48 @@ def route_ports_to_x(
         add_port(p, y_optical_top, routes, ports)
         y_optical_top += separation
 
-    start_straight = 0.01
-    start_straight0 = 0
+    start_straight_length_section = start_straight_length
     max_x = max(xs)
     min_x = min(xs)
 
     for p in backward_ports_thru_north:
         # Extend ports if necessary
         if angle == 0 and p.x < max_x:
-            start_straight0 = max_x - p.x
+            start_straight_length_section = max_x - p.x
         elif angle == 180 and p.x > min_x:
-            start_straight0 = p.x - min_x
+            start_straight_length_section = p.x - min_x
         else:
-            start_straight0 = 0
+            start_straight_length_section = 0
 
         add_port(
             p,
             y_optical_top,
             routes,
             ports,
-            start_straight=start_straight + start_straight0,
+            start_straight_length=start_straight_length + start_straight_length_section,
         )
         y_optical_top += separation
-        start_straight += separation
+        start_straight_length += separation
 
-    start_straight = 0.01
-    start_straight0 = 0
+    start_straight_length_section = start_straight_length
     for p in backward_ports_thru_south:
         # Extend ports if necessary
         if angle == 0 and p.x < max_x:
-            start_straight0 = max_x - p.x
+            start_straight_length_section = max_x - p.x
         elif angle == 180 and p.x > min_x:
-            start_straight0 = p.x - min_x
+            start_straight_length_section = p.x - min_x
         else:
-            start_straight0 = 0
+            start_straight_length_section = 0
 
         add_port(
             p,
             y_optical_bot,
             routes,
             ports,
-            start_straight=start_straight + start_straight0,
+            start_straight_length=start_straight_length + start_straight_length_section,
         )
         y_optical_bot -= separation
-        start_straight += separation
+        start_straight_length += separation
 
     return routes, ports
 
@@ -303,6 +301,7 @@ def route_ports_to_y(
     extend_right: float = 0.0,
     routing_func: Callable = get_route,
     backward_port_side_split_index: int = 0,
+    start_straight_length: float = 0.01,
     **routing_func_args: Dict[Any, Any],
 ) -> Tuple[List[Route], List[Port]]:
     """
@@ -405,8 +404,10 @@ def route_ports_to_y(
     routes = []
     ports = []
 
-    def add_port(p, x, l_elements, l_ports, start_straight=0.01):
-        new_port = p._copy()
+    def add_port(
+        p, x, l_elements, l_ports, start_straight_length=start_straight_length
+    ):
+        new_port = p.copy()
         new_port.angle = angle
         new_port.position = (x, y + extension_length)
 
@@ -419,7 +420,7 @@ def route_ports_to_y(
                 routing_func(
                     p,
                     new_port,
-                    start_straight=start_straight,
+                    start_straight_length=start_straight_length,
                     radius=radius,
                     **routing_func_args,
                 )
@@ -447,17 +448,29 @@ def route_ports_to_y(
         add_port(p, x_optical_right, routes, ports)
         x_optical_right += separation
 
-    start_straight = 0.01
+    start_straight_length_section = start_straight_length
     for p in backward_ports_thru_east:
-        add_port(p, x_optical_right, routes, ports, start_straight=start_straight)
+        add_port(
+            p,
+            x_optical_right,
+            routes,
+            ports,
+            start_straight_length=start_straight_length_section,
+        )
         x_optical_right += separation
-        start_straight += separation
+        start_straight_length_section += separation
 
-    start_straight = 0.01
+    start_straight_length_section = start_straight_length
     for p in backward_ports_thru_west:
-        add_port(p, x_optical_left, routes, ports, start_straight=start_straight)
+        add_port(
+            p,
+            x_optical_left,
+            routes,
+            ports,
+            start_straight_length=start_straight_length_section,
+        )
         x_optical_left -= separation
-        start_straight += separation
+        start_straight_length_section += separation
 
     return routes, ports
 
