@@ -1,6 +1,6 @@
-"""One problem is that when we add references we have to make sure they have unique names.
+"""when you add references you have to make sure they have unique names.
 
-The photonics package `gf. has a cell decorator that names the objects that it produces depending on the parameters that we pass them
+the cell decorator gives unique names to components that depend on their parameters
 """
 
 
@@ -11,7 +11,7 @@ from gdsfactory.component import Component
 
 
 @gf.cell
-def straight_cell(width: Union[float, int] = 10, height: int = 1) -> Component:
+def straight(width: Union[float, int] = 10, height: int = 1) -> Component:
     """Returns straight with automatic name."""
     wg = gf.Component("straight")
     wg.add_polygon([(0, 0), (width, 0), (width, height), (0, height)])
@@ -23,16 +23,16 @@ def straight_cell(width: Union[float, int] = 10, height: int = 1) -> Component:
 
 
 def test_autoname() -> None:
-    c = straight_cell()
-    assert c.name == "straight_cell"
-
-    c = straight_cell(width=0.5)
-    assert c.name == "straight_cell_width500n"
+    c = straight()
+    assert c.name.split("_")[0] == "straight"
 
 
 if __name__ == "__main__":
-    c = straight_cell()
-    print(c)
+    c1 = straight()
+    print(c1)
 
-    c = straight_cell(width=0.5)
-    print(c)
+    c2 = straight(width=0.5)
+    print(c2)
+
+    c3 = straight(0.5)
+    assert c2.name == c3.name
