@@ -46,7 +46,7 @@ def test_netlist_yaml() -> Component:
         o1: mmi_long,o1
     """
 
-    c = gf.component_from_yaml(yaml)
+    c = gf.read.from_yaml(yaml)
     return c
 
 
