@@ -1,12 +1,11 @@
 """
-This is a convenience function for cascading components. Usecase, is composite
-straights such as phase modulators, where we need to keep track of multiple tapers,
-doped sections, undopped, heaters etc...
+You can use component_sequence as a convenient function for cascading components,
+where you need to keep track of multiple tapers, doped sections, heaters etc...
 
 The idea is to associate one symbol per type of section.
-A section is uniquely defined by the component, its selected input and its selected output.
+A section is uniquely defined by the component, input port name and output port name.
 
-The mapping between symbols and components is supplied by a dictionnary.
+The mapping between symbols and components is supplied by a dictionary.
 The actual chain of components is supplied by a string or a list
 """
 
@@ -15,16 +14,16 @@ from gdsfactory.component import Component
 from gdsfactory.components import bend_circular
 from gdsfactory.components.component_sequence import component_sequence
 from gdsfactory.components.straight import straight
-from gdsfactory.components.straight_pin import straight_pin
+from gdsfactory.components.straight_pin import straight_pn
 
 
 @gf.cell
-def test_cutback_heater() -> Component:
+def test_cutback_pn() -> Component:
     # Define subcomponents
     bend_radius = 10.0
     bend180 = bend_circular(radius=bend_radius, angle=180)
     wg = straight(length=5.0)
-    wg_heater = straight_pin(length=20.0)
+    wg_heater = straight_pn(length=50.0)
 
     # Define a map between symbols and (component, input port, output port)
     symbol_to_component = {
@@ -36,7 +35,7 @@ def test_cutback_heater() -> Component:
 
     # Generate a sequence
     # This is simply a chain of characters. Each of them represents a component
-    # with a given input and and a given output
+    # with a given input and a given output
 
     sequence = "AB-H-H-H-H-BA"
     component = component_sequence(
@@ -46,5 +45,5 @@ def test_cutback_heater() -> Component:
 
 
 if __name__ == "__main__":
-    c = test_cutback_heater()
+    c = test_cutback_pn()
     c.show()
