@@ -8,11 +8,13 @@ def is_on_grid(x: float, nm: int = 1) -> bool:
 
 
 def assert_on_1nm_grid(x: float) -> None:
-    assert np.isclose(snap_to_grid(x), x), f"{x} needs to be on 1nm grid"
+    x_grid = snap_to_grid(x)
+    assert np.isclose(x_grid, x), f"{x} needs to be on 1nm grid, try {x_grid}"
 
 
 def assert_on_2nm_grid(x: float) -> None:
-    assert np.isclose(snap_to_2nm_grid(x), x), f"{x} needs to be on 1nm grid"
+    x_grid = snap_to_2nm_grid(x)
+    assert np.isclose(x_grid, x), f"{x} needs to be on 2nm grid, try {x_grid}"
 
 
 def snap_to_grid(
