@@ -23,8 +23,7 @@ def _test_hash_array_file():
     c.add_array(wg)
     gdspath = c.write_gds()
     h = hash_file(gdspath)
-    print(h)
-    assert h == "bec2ab8f157b429bd6ff210bedde6fe3"
+    assert h == "71d476075cf081b4099c1eea1c8984a1", h
 
 
 def _test_hash_file():
@@ -34,8 +33,7 @@ def _test_hash_file():
     c.add_label("hi")
     gdspath = c.write_gds()
     h = hash_file(gdspath)
-    print(h)
-    assert h == "71655c3f7ab57e7a48b55683e8c1bfc4"
+    assert h == "f2228aed8141f447e601ce93a6219415", h
 
 
 if __name__ == "__main__":
