@@ -17,14 +17,14 @@ def test_validator_pass():
     component_with_straight(component=component)
 
 
-def test_validator_fail_empty():
-    component = gf.Component()
-    with pytest.raises(pydantic.ValidationError):
-        component_with_straight(component=component)
+# def test_validator_fail_empty():
+#     component = gf.Component()
+#     with pytest.raises(pydantic.ValidationError):
+#         component_with_straight(component=component)
 
 
 def test_validator_fail_name_too_long():
-    component = gf.Component(name="a" * 33)
+    component = gf.Component(name="a" * 200)
 
     # component_with_straight(component=component)
     with pytest.raises(pydantic.ValidationError):
